<?php

namespace App\Domains\Product\Http\Controllers\Backend;
use App\Domains\Product\Http\Requests\Product\ArrivalCheckProductRequest;
use App\Domains\Product\Http\Requests\Product\CreateProductRequest;
use App\Domains\Product\Http\Requests\Product\PreCheckProductRequest;
use App\Domains\Product\Jobs\ArrivalCheckJob;
use App\Domains\Product\Jobs\ProductCreateJob;
use App\Domains\Product\Models\Product;
use App\Domains\Product\Models\Setting\RecommendedSize;
use App\Domains\Product\Models\Setting\Material;
use App\Domains\Product\Services\BrandService;
use App\Domains\Product\Services\BundleDealService;
use App\Domains\Product\Services\DamagePresetService;
use App\Domains\Product\Services\ReworkService;
use App\Domains\Product\Services\TruesizeService;
use App\Domains\Product\Services\DetailService;
use App\Domains\Product\Services\EmbroideredPrintedService;
use App\Domains\Product\Services\EraService;
use App\Domains\Product\Services\GenderService;
use App\Domains\Product\Services\ProductService;
use App\Domains\Product\Services\SettingService;
use App\Domains\Product\Services\SizeOnLabelService;
use App\Domains\Product\Services\TypeService;
use App\Domains\Product\Services\VariantService;
use App\Domains\Product\Services\RecommendedSizeService;
use App\Domains\Product\Services\MaterialService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class ProductController
{
    protected $productService;
    protected $settingService;
    protected $typeService;
    protected $brandService;
    protected $damagePreset;
    protected $rework;
    protected $truesize;
    protected $sizeOnLabelService;
    protected $embroideredPrintedService;
    protected $detailService;
    protected $variantService;
    protected $bundleDealService;
    protected $genderService;
    protected $eraService;
    protected $recommendedSizeService;
    protected $materialService;

    public function __construct(
        ProductService $productService,
        TypeService $typeService,
        BrandService $brandService,
        DamagePresetService $damagePreset,
        ReworkService $rework,
        TruesizeService $truesize,
        SizeOnLabelService $sizeOnLabelService,
        EmbroideredPrintedService $embroideredPrintedService,
        VariantService $variantService,
        DetailService $detailService,
        SettingService $settingService,
        BundleDealService $bundleDealService,
        GenderService $genderService,
        EraService $eraService,
        RecommendedSizeService $recommendedSizeService,
        MaterialService $materialService
    )
    {
        $this->productService = $productService;
        $this->typeService = $typeService;
        $this->brandService = $brandService;
        $this->damagePresetService = $damagePreset;
        $this->reworkService = $rework;
        $this->truesizeService = $truesize;
        $this->sizeOnLabelService = $sizeOnLabelService;
        $this->embroideredPrintedService = $embroideredPrintedService;
        $this->variantService = $variantService;
        $this->detailService = $detailService;
        $this->settingService = $settingService;
        $this->bundleDealService = $bundleDealService;
        $this->genderService = $genderService;
        $this->eraService = $eraService;
        $this->recommendedSizeService = $recommendedSizeService;
        $this->materialService = $materialService;
    }

    public function setBarcodeData(Request $request)
    {
        $dbProduct = Product::where('id', (int) $request->product_id)->first();
        $dbProduct->shopify_response = str_replace("RWUK", "MARKET", $dbProduct->shopify_response);
        $dbProduct->shopify_response = str_replace("VCUK", "MARKET", $dbProduct->shopify_response);
        if (!str_contains($dbProduct->shopify_response, 'BRICKLANE')) {
            $dbProduct->shopify_response = str_replace('"tags":"', '"tags":"BRICKLANE, ', $dbProduct->shopify_response);
            $dbProduct->shopify_response = str_replace('"tags": "', '"tags": "BRICKLANE, ', $dbProduct->shopify_response);
        }

        $dbProduct->save();


        if($dbProduct->rework)
        {
            $updatedDescription = str_replace("RWUK", "MARKET", json_decode($dbProduct->shopify_response)->product->body_html);
        }else {
            $updatedDescription = str_replace("VCUK", "MARKET", json_decode($dbProduct->shopify_response)->product->body_html);
        }


        isset($dbProduct->gender[0]) ? $tagsCollect[] = $dbProduct->gender[0] : NULL;
        ($dbProduct->not_depop == 1) ? $tagsCollect[] = 'NOTDEPOP' : NULL;
        ($dbProduct->not_asos == 1) ? $tagsCollect[] = 'NOTASOS' : NULL;
        ($dbProduct->gg == 1) ? $tagsCollect[] = 'GG': NULL;

        isset($dbProduct->barcode) ? $tagsCollect[] = "BRICKLANE" : NULL;

        isset($dbProduct->depop_link) ? $tagsCollect[] = $dbProduct->depop_link : NULL;
        isset($dbProduct->asos_link) ? $tagsCollect[] = $dbProduct->asos_link : NULL;



        $client = new \GuzzleHttp\Client();
        $headers = [
            'headers' => [
                'x-shopify-access-token' => config('shopify.shopify_access_token'),
                'content-type' => 'application/json'
            ],
            'body' => json_encode([
                "product" => [
                    "id" => $dbProduct->id,
                    "tags" => $tagsCollect,
                    "body_html" => $updatedDescription,
                ]
            ])
        ];
        $response = $client->request('PUT', config('shopify.shopify_domain').'/admin/api/'.config('shopify.shopify_api_version').'/products/'.json_decode($dbProduct->shopify_response)->product->id.'.json', $headers);
        $data = json_decode($response->getBody()->getContents());

        return $data;

    }

    public function create(Product $product = null)
    {
	$unique_tag = Auth::user()->tag;
        return view('backend.product.create')
	    ->with('unique_tag', $unique_tag)
            ->withProduct($product)
            ->withTypes($this->typeService->getTypes())
            ->withTypeFields($this->typeService->getTypeFields())
            ->withBrands($this->brandService->getBrands())
            ->withDamagePresets($this->damagePresetService->getDamagePreset())
            ->withReworks($this->reworkService->getRework())
            ->withTruesizes($this->truesizeService->getTruesize())
            ->withSizeOnLabels($this->sizeOnLabelService->getSizeOnLabel())
            ->withEmbroideredPrinted($this->embroideredPrintedService->getEmbroideredPrinted())
            ->withVariants($this->variantService->getVariants())
            ->withGenders($this->genderService->getGenders())
            ->withRecommendedSizes($this->recommendedSizeService->getRecommendedSizes())
            ->withMaterials($this->materialService->getMaterials());
    }

    public function store(CreateProductRequest $request)
    {
//         dd($request->all());
       dispatch(new ProductCreateJob($request->all(), $this->productService));
//       $product = $this->productService->store($request->all());


       return response()->json([
           'unique_tag' => $this->productService->getTag(true)
       ]);
    }

    public function edit(Product $product)
    {
        $product->recommended_size = RecommendedSize::find($product->recommended_size_id);
        $product->material = Material::find($product->material_id);
        return view('backend.product.edit')
            ->withProduct($product)
            ->withDamagePresets($this->damagePresetService->getDamagePreset())
            ->withReworks($this->reworkService->getRework())
            ->withTruesizes($this->truesizeService->getTruesize())
            ->withSizeOnLabels($this->sizeOnLabelService->getSizeOnLabel())
            ->withEmbroideredPrinted($this->embroideredPrintedService->getEmbroideredPrinted())
            ->withTypes($this->typeService->getTypes())
            ->withTypeFields($this->typeService->getTypeFields())
            ->withProductTypeFields($this->typeService->getProductTypeFields($product->id))
            ->withBrands($this->brandService->getBrands())
            ->withVariants($this->variantService->getVariants())
            ->withDetails($this->detailService->getDetails())
            ->withProductDetails($this->detailService->getProductDetails($product->id))
            ->withProductVariants($this->variantService->getProductVariants($product->id))
            ->withGenders($this->genderService->getGenders())
            ->withRecommendedSizes($this->recommendedSizeService->getRecommendedSizes())
            ->withMaterials($this->materialService->getMaterials());
    }

    public function update(Product $product, CreateProductRequest $request)
    {
        $this->productService->update($product, $request->all());
        return back()->withFlashSuccess(__('The product was successfully arrival checked.'));
    }

    public function preCheckProduct(Product $product)
    {
        return view('backend.product.prechecks-create')
            ->withProduct($product)
            ->withTypes($this->typeService->getTypes())
            ->withTypeFields($this->typeService->getTypeFields())
            ->withProductTypeFields($this->typeService->getProductTypeFields($product->id))
            ->withBrands($this->brandService->getBrands())
            ->withVariants($this->variantService->getVariants())
            ->withDetails($this->detailService->getDetails())
            ->withProductDetails($this->detailService->getProductDetails($product->id))
            ->withProductVariants($this->variantService->getProductVariants($product->id));
    }

    public function preCheckProductStore(Product $product, PreCheckProductRequest $request)
    {
        $product = $this->productService->preCheckProductStore($product, $request->all());
        return redirect()->route('admin.product.arrival_check.product', $product->id)->withFlashSuccess(__('The product was successfully pre-checked.'));
    }

    public function arrivalCheck()
    {
        $product = $this->productService->getFirstProductForArrivalCheck();
        if ($product)
        {
            return redirect()->route('admin.product.arrival_check.product', $product->id);
        }
        return redirect()->route('admin.product.all')->withFlashDanger(__('Not any product found for Arrival Check.'));
    }

    public function arrivalCheckProduct(Product $product)
    {
        if(isset($product->shopify_response) && !empty($product->shopify_response)) 
        {
            $client = new \GuzzleHttp\Client();
            $headers = [
                'headers' => [
                    'x-shopify-access-token' => config('shopify.shopify_access_token'),
                    'content-type' => 'application/json'
                ]
            ];
            // order=title desc
            $response = $client->request('GET', config('shopify.shopify_domain').'/admin/api/'.config('shopify.shopify_api_version').'/products.json?ids='.json_decode($product->shopify_response)->product->id,$headers);
            $shopifyProduct = json_decode($response->getBody()->getContents());

            if(isset($shopifyProduct->products) && $shopifyProduct->products != [])
            {
                $dbProduct = Product::find($product->id);
                $product->barcode = $shopifyProduct->products[0]->variants[0]->barcode;
                $dbProduct->barcode = $product->barcode;
                $dbProduct->save();
            }
        }
        
        $product->recommended_size = RecommendedSize::find($product->recommended_size_id);
        $product->material = Material::find($product->material_id);
        return view('backend.product.arrival-checks-create')
            ->withProduct($product)
            ->withDamagePresets($this->damagePresetService->getDamagePreset())
            ->withReworks($this->reworkService->getRework())
            ->withTruesizes($this->truesizeService->getTruesize())
            ->withSizeOnLabels($this->sizeOnLabelService->getSizeOnLabel())
            ->withEmbroideredPrinted($this->embroideredPrintedService->getEmbroideredPrinted())
            ->withTypes($this->typeService->getTypes())
            ->withTypeFields($this->typeService->getTypeFields())
            ->withProductTypeFields($this->typeService->getProductTypeFields($product->id))
            ->withBrands($this->brandService->getBrands())
            ->withVariants($this->variantService->getVariants())
            ->withDetails($this->detailService->getDetails())
            ->withProductDetails($this->detailService->getProductDetails($product->id))
            ->withProductVariants($this->variantService->getProductVariants($product->id))
            ->withGenders($this->genderService->getGenders())
            ->withEras($this->eraService->getEras())
            ->withRecommendedSizes($this->recommendedSizeService->getRecommendedSizes())
            ->withMaterials($this->materialService->getMaterials());
    }

    public function arrivalCheckProductStore(Product $product, ArrivalCheckProductRequest $request)
    {
        // dd($request->all());
        $product->update([
            'stage' => Product::STAGE_HOLD,
            'damage_preset' => $request->damage_preset,
            'reworks' => isset($request->rework)? $request->rework : null,
            'truesizes' => $request->true_size,
        ]);
        dispatch(new ArrivalCheckJob($request->all(), $product, $this->productService));
        //  $this->productService->arrivalCheckProductStore($product, $request->all());
        return redirect()->route('admin.product.arrival_check')->withFlashSuccess(__('The product was successfully arrival checked.'));
    }

    public function arrivalCheckSearch(Request $request)
    {
        $product = $this->productService->arrivalCheckSearch($request->all());
        if (!$product)
        {
            return back()->withFlashDanger(__('The product was not found.'));
        }
        return redirect()->route('admin.product.arrival_check.product', $product->id)
            ->withProduct($product);
    }

    public function uploads()
    {
        $product = $this->productService->getFirstProductForUpload();
        if ($product)
        {
            return redirect()->route('admin.product.upload.product', $product->id);
        }
        return redirect()->route('admin.product.all')->withFlashDanger(__('Not any product found that is uploaded.'));
    }

    public function uploadProduct(Product $product)
    {
        if ($this->productService->checkProductQuantity($product))
        {
            return redirect()->route('admin.product.uploaded');
        }

        return view('backend.product.upload-create')
            ->withProduct($product)
            ->withDamagePresets($this->damagePresetService->getDamagePreset())
            ->withReworks($this->reworkService->getRework())
            ->withTruesizes($this->truesizeService->getTruesize())
            ->withSizeOnLabels($this->sizeOnLabelService->getSizeOnLabel())
            ->withEmbroideredPrinted($this->embroideredPrintedService->getEmbroideredPrinted())
            ->withTypes($this->typeService->getTypes())
            ->withTypeFields($this->typeService->getTypeFields())
            ->withProductTypeFields($this->typeService->getProductTypeFields($product->id))
            ->withBrands($this->brandService->getBrands())
            ->withVariants($this->variantService->getVariants())
            ->withDetails($this->detailService->getDetails())
            ->withProductDetails($this->detailService->getProductDetails($product->id))
            ->withProductVariants($this->variantService->getProductVariants($product->id));
    }

    public function uploadProductStore(Product $product, Request $request)
    {
        $this->productService->uploadProductStore($product, $request->all());
        return redirect()->route('admin.product.uploaded')->withFlashSuccess(__('The product was successfully uploaded.'));
    }

    public function storePhotos(Request $request)
    {
        return $this->productService->storePhotos($request->all());
    }

    public function delete(Product $product, Request $request)
    {
        $this->productService->delete($product, $request->all());
        return back()->withFlashSuccess(__('The product was successfully deleted.'));
    }

    public function restore(Product $product)
    {
        $this->productService->restore($product);
        return back()->withFlashSuccess(__('The product was successfully restored.'));
    }

//    public function getShopifyProduct($id){
//        $shopifyProduct = $this->productService->getShopifyProduct($id);
//        if(isset($shopifyProduct->product->variants[0]->inventory_quantity) && $shopifyProduct->product->variants[0]->inventory_quantity == 0)
//        {
//            dd('Not Available');
//        }
//    }

}
