<?php

namespace App\Domains\Product\Http\Controllers\Backend\Setting;

use App\Domains\Product\Services\BrandService;
use App\Domains\Product\Services\BundleDealService;
use App\Domains\Product\Services\DamagePresetService;
use App\Domains\Product\Services\ReworkService;
use App\Domains\Product\Services\TruesizeService;
use App\Domains\Product\Services\DetailService;
use App\Domains\Product\Services\EmbroideredPrintedService;
use App\Domains\Product\Services\EraService;
use App\Domains\Product\Services\GenderService;
use App\Domains\Product\Services\GenderSizeGuideService;
use App\Domains\Product\Services\ProductService;
use App\Domains\Product\Services\SettingService;
use App\Domains\Product\Services\SizeOnLabelService;
use App\Domains\Product\Services\TypeService;
use App\Domains\Product\Services\VariantService;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

class SettingController extends Controller
{
    protected $productService;
    protected $settingService;
    protected $typeService;
    protected $brandService;
    protected $damagePreset;
    protected $rework;
    protected $truesize;
    protected $sizeOnLabelService;
    protected $embroideredPrintedService;
    protected $detailService;
    protected $variantService;
    protected $bundleDealService;
    protected $genderSizeGuideService;
    protected $genderService;

    public function __construct(
        ProductService $productService,
        TypeService $typeService,
        BrandService $brandService,
        DamagePresetService $damagePreset,
        ReworkService $rework,
        TruesizeService $truesize,
        SizeOnLabelService $sizeOnLabelService,
        EmbroideredPrintedService $embroideredPrintedService,
        VariantService $variantService,
        DetailService $detailService,
        SettingService $settingService,
        BundleDealService $bundleDealService,
        GenderSizeGuideService $genderSizeGuideService,
        GenderService $genderService,
        EraService $eraService
    )
    {
        $this->productService = $productService;
        $this->typeService = $typeService;
        $this->brandService = $brandService;
        $this->damagePresetService = $damagePreset;
        $this->reworkService = $rework;
        $this->truesizeService = $truesize;
        $this->sizeOnLabelService = $sizeOnLabelService;
        $this->embroideredPrintedService = $embroideredPrintedService;
        $this->variantService = $variantService;
        $this->detailService = $detailService;
        $this->settingService = $settingService;
        $this->bundleDealService = $bundleDealService;
        $this->genderSizeGuideService = $genderSizeGuideService;
        $this->genderService = $genderService;
        $this->eraService = $eraService;

    }

    public function index()
    {
        return view('backend.setting.index')
            ->withDamagePresets($this->damagePresetService->getDamagePreset())
            ->withReworks($this->reworkService->getRework())
            ->withTruesizes($this->truesizeService->getTruesize())
            ->withSizeOnLabels($this->sizeOnLabelService->getSizeOnLabel())
            ->withEmbroideredPrinted($this->embroideredPrintedService->getEmbroideredPrinted())
            ->withTypes($this->typeService->getTypes())
            ->withTypeFields($this->typeService->getTypeFields())
            ->withBrands($this->brandService->getBrands())
            ->withVariants($this->variantService->getRawVariants())
            ->withDetails($this->detailService->getDetails())
            ->withBundleDeals($this->bundleDealService->getBundleDeal())
            ->withGenderSizeGuides($this->genderSizeGuideService->getGenderSizeGuide())
            ->withGenders($this->genderService->getGenders())
            ->withEras($this->eraService->getEras());
    }

    public function store(Request $request)
    {
        $this->settingService->store($request->all());
        return back()->withFlashSuccess(__('The setting was successfully updated.'));
    }

}
