<?php

namespace App\Domains\Product\Http\Controllers\Backend\Setting;

use App\Domains\Product\Models\UniqueTag;
use App\Domains\Product\Services\TagService;
use App\Exceptions\GeneralException;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

class TagController extends Controller
{
    protected $tagService;

    /**
     * @param TagService $tagService
     */
    public function __construct(TagService $tagService)
    {
        $this->tagService = $tagService;
    }

    /**
     * @param Request $request
     * @return mixed
     * @throws GeneralException
     */
    public function tagStore(Request $request): mixed
    {
        $this->tagService->create($request->all());
        return back()->withFlashSuccess(__('The Tag was successfully created.'));
    }

    /**
     * @param UniqueTag $tag
     * @param Request $request
     * @return mixed
     * @throws GeneralException
     */
    public function tagUpdate(UniqueTag $tag, Request $request): mixed
    {
        $this->tagService->update($tag, $request->all());
        return back()->withFlashSuccess(__('The Tag was successfully updated.'));
    }

    /**
     * @param UniqueTag $tag
     * @param Request $request
     * @return mixed
     * @throws GeneralException
     */
    public function tagDelete(UniqueTag $tag, Request $request): mixed
    {
        $this->tagService->delete($tag, $request->all());
        return back()->withFlashSuccess(__('The Tag was successfully deleted.'));
    }
}
