<?php

namespace App\Domains\Product\Models;

use App\Domains\Product\Models\Traits\Relationship\ProductRelationship;
use App\Domains\Product\Models\Traits\Scope\ProductScope;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\SoftDeletes;

class Product extends Model
{
    public const STAGE_CREATED = "created";
    public const STAGE_PRE_CHECK = "pre_check";
    public const STAGE_ARRIVAL_CHECK = "arrival_check";
    public const STAGE_UPLOADED = "uploaded";
    public const STAGE_OUT_OF_STOCK = "out_of_stock";
    public const STAGE_HOLD = "hold";

    use HasFactory, ProductRelationship, ProductScope, SoftDeletes;

    protected $fillable = [
        'type_id',
        'damage_preset',
        'size_on_label',
        'brand_id',
        'embroidered_or_printed',
        'gender',
        'unique_tag',
        'price',
        'gg',
        'fake',
        'not_depop',
        'not_asos',
        'vcuk',
        'stage',
        'depop_link',
        'asos_link',
        'era',
        'shopify_response',
        'recommended_size_id',
        'material_id',
        "created",
        "pre_check",
        "arrival_check",
        "uploaded",
        "out_of_stock",
        "reworks",
        "truesizes",
        "user_id"
    ];

    protected $append = ['price_formated'];

    public function getPriceAttribute($value)
    {
        return (float)$value;
    }

    public function getPriceFormatedAttribute()
    {
        return priceRound((float)$this->price);
    }

    public static function boot()
    {
        parent::boot();

        static::saved(function ($item) {
            Product::where('id', $item->id)->update([$item->stage => now()]);
        });

    }

    /**
     * @return BelongsTo
     */
    public function user(): BelongsTo
    {
        return $this->belongsTo(Product::class);
    }
}
