<?php

namespace App\Domains\Product\Services;

use App\Domains\Product\Models\Setting\Brand;
use App\Exceptions\GeneralException;
use App\Services\BaseService;
use Illuminate\Support\Facades\DB;

class BrandService extends BaseService
{
    protected $brand;

    public function __construct(Brand $brand)
    {
        $this->model = $brand;
    }

    public function getBrands()
    {
        return $this->model->oldest('name')->get(['id', 'name', 'shopify_value']);
    }

    public function create(array $data = []): Brand|null
    {

        try {
            $brand = $this->model->create([
                'name' => $data['name'],
                'shopify_value' => $data['shopify_value'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Brand. Please try again.'));
        }


        return $brand;
    }

    public function update(Brand $brand, array $data = []): Brand|null
    {

        try {
            $brand->update([
                'name' => $data['name'],
                'shopify_value' => $data['shopify_value'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Brand. Please try again.'));
        }


        return $brand;
    }

    public function delete(Brand $brand): Brand|null
    {
        if ($this->deleteById($brand->id)) {
            return $brand;
        }
        throw new GeneralException('There was a problem deleting this Brand. Please try again.');
    }
}
