<?php

namespace App\Domains\Product\Services;

use App\Domains\Product\Models\Setting\BundleDeal;
use App\Exceptions\GeneralException;
use App\Services\BaseService;
use Illuminate\Support\Facades\DB;

class BundleDealService extends BaseService
{
    protected $bundleDeal;

    public function __construct(BundleDeal $bundleDeal)
    {
        $this->model = $bundleDeal;
    }

    public function getBundleDeal()
    {
        return $this->model->oldest('type_id')->get(['id', 'value', 'type_id']);
    }


    public function create(array $data = []): BundleDeal|null
    {

        try {
            $bundleDeal = $this->model->create([
                'value' => $data['value'],
                'type_id' => $data['type_id'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Bundle Deal. Please try again.'));
        }

        return $bundleDeal;
    }

    public function update(BundleDeal $bundleDeal, array $data = []): BundleDeal|null
    {

        try {
            $bundleDeal->update([
                'value' => $data['value'],
                'type_id' => $data['type_id'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Bundle Deal. Please try again.'));
        }

        return $bundleDeal;
    }

    public function delete(BundleDeal $bundleDeal): BundleDeal|null
    {
        if ($this->deleteById($bundleDeal->id)) {
            return $bundleDeal;
        }
        throw new GeneralException('There was a problem deleting this Bundle Deal. Please try again.');
    }
}
