<?php

namespace App\Domains\Product\Services;

use App\Domains\Product\Models\Setting\DamagePreset;
use App\Exceptions\GeneralException;
use App\Services\BaseService;

class DamagePresetService extends BaseService
{
    protected $damagePreset;

    public function __construct(DamagePreset $damagePreset)
    {
        $this->model = $damagePreset;
    }

    public function getDamagePreset()
    {
        return $this->model->oldest('name')->get(['id', 'name']);
    }

    public function create(array $data = []): DamagePreset|null
    {

        try {
            $damagePreset = $this->model->create([
                'name' => $data['name'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Damage Preset. Please try again.'));
        }

        return $damagePreset;
    }

    public function update(DamagePreset $damagePreset, array $data = []): DamagePreset|null
    {

        try {
            $damagePreset->update([
                'name' => $data['name'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Damage Preset. Please try again.'));
        }

        return $damagePreset;
    }

    public function delete(DamagePreset $damagePreset): DamagePreset|null
    {
        if ($this->deleteById($damagePreset->id)) {
            return $damagePreset;
        }
        throw new GeneralException('There was a problem deleting this Damage Preset. Please try again.');
    }
}
