<?php

namespace App\Domains\Product\Services;

use App\Domains\Product\Models\ProductDetail;
use App\Domains\Product\Models\Setting\Detail;
use App\Exceptions\GeneralException;
use App\Services\BaseService;
use Illuminate\Support\Facades\DB;

class DetailService extends BaseService
{
    protected $detail;
    protected $productDetail;

    public function __construct(Detail $detail, ProductDetail $productDetail)
    {
        $this->model = $detail;
        $this->productDetailModel = $productDetail;
    }

    public function getDetails()
    {
        return $this->model->oldest('name')->get(['id', 'name', 'value']);
    }

    public function getProductDetails($product_id)
    {
        return $this->productDetailModel->where('product_id', $product_id)->get(['id', 'name', 'value']);
    }

    public function create(array $data = []): Detail|null
    {

        try {
            $detail = $this->model->create([
                'name' => $data['name'],
                'value' => $data['value'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Detail. Please try again.'));
        }

        return $detail;
    }

    public function update(Detail $detail, array $data = []): Detail|null
    {

        try {
            $detail->update([
                'name' => $data['name'],
                'value' => $data['value'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Detail. Please try again.'));
        }

        return $detail;
    }

    public function delete(Detail $detail): Detail|null
    {
        if ($this->deleteById($detail->id)) {
            return $detail;
        }
        throw new GeneralException('There was a problem deleting this Detail. Please try again.');
    }
}
