<?php

namespace App\Domains\Product\Services;

use App\Domains\Product\Models\Setting\EmbroideredPrinted;
use App\Exceptions\GeneralException;
use App\Services\BaseService;
use Illuminate\Support\Facades\DB;

class EmbroideredPrintedService extends BaseService
{
    protected $embroideredPrinted;

    public function __construct(EmbroideredPrinted $embroideredPrinted)
    {
        $this->model = $embroideredPrinted;
    }

    public function getEmbroideredPrinted()
    {
        return $this->model->latest()->get(['id', 'name']);
    }

    public function create(array $data = []): EmbroideredPrinted|null
    {

        try {
            $embroideredPrinted = $this->model->create([
                'name' => $data['name'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Embroidered Printed. Please try again.'));
        }

        return $embroideredPrinted;
    }

    public function update(EmbroideredPrinted $embroideredPrinted, array $data = []): EmbroideredPrinted|null
    {

        try {
            $embroideredPrinted->update([
                'name' => $data['name'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Embroidered Printed. Please try again.'));
        }

        return $embroideredPrinted;
    }

    public function delete(EmbroideredPrinted $embroideredPrinted): EmbroideredPrinted|null
    {
        if ($this->deleteById($embroideredPrinted->id)) {
            return $embroideredPrinted;
        }
        throw new GeneralException('There was a problem deleting this Embroidered Printed. Please try again.');
    }
}
