<?php

namespace App\Domains\Product\Services;

use App\Domains\Product\Models\Setting\Era;
use App\Exceptions\GeneralException;
use App\Services\BaseService;
use Illuminate\Support\Facades\DB;

class EraService extends BaseService
{
    protected $era;

    public function __construct(Era $era)
    {
        $this->model = $era;
    }

    public function getEras()
    {
        return $this->model->get(['id', 'era']);
    }

    public function create(array $data = []): Era|null
    {

        try {
            $era = $this->model->create([
                'era' => $data['era'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Era. Please try again.'));
        }

        return $era;
    }

    public function update(Era $era, array $data = []): Era|null
    {

        try {
            $era->update([
                'era' => $data['era'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Era. Please try again.'));
        }

        return $era;
    }

    public function delete(Era $era): Era|null
    {
        if ($this->deleteById($era->id)) {
            return $era;
        }
        throw new GeneralException('There was a problem deleting this Era. Please try again.');
    }
}
