<?php

namespace App\Domains\Product\Services;

use App\Domains\Product\Models\Setting\Gender;
use App\Exceptions\GeneralException;
use App\Services\BaseService;
use Illuminate\Support\Facades\DB;

class GenderService extends BaseService
{
    protected $gender;

    public function __construct(Gender $gender)
    {
        $this->model = $gender;
    }

    public function getGenders()
    {
        return $this->model->oldest('gender')->get(['id', 'gender']);
    }

    public function create(array $data = []): Gender|null
    {

        try {
            $gender = $this->model->create([
                'gender' => $data['gender'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Gender. Please try again.'));
        }

        return $gender;
    }

    public function update(Gender $gender, array $data = []): Gender|null
    {

        try {
            $gender->update([
                'gender' => $data['gender'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Gender. Please try again.'));
        }

        return $gender;
    }

    public function delete(Gender $gender): Gender|null
    {
        if ($this->deleteById($gender->id)) {
            return $gender;
        }
        throw new GeneralException('There was a problem deleting this Gender. Please try again.');
    }
}
