<?php

namespace App\Domains\Product\Services;

use App\Domains\Product\Models\Setting\GenderSizeGuide;
use App\Exceptions\GeneralException;
use App\Services\BaseService;
use Illuminate\Support\Facades\DB;

class GenderSizeGuideService extends BaseService
{
    protected $genderSizeGuide;

    public function __construct(GenderSizeGuide $genderSizeGuide)
    {
        $this->model = $genderSizeGuide;
    }

    public function getGenderSizeGuide()
    {
        return $this->model->get();
    }


    public function create(array $data = []): GenderSizeGuide|null
    {

        try {
            $genderSizeGuide = $this->model->create([
                'type_id' => $data['type_id'],
                'size_on_label' => $data['size_on_label'],
                'values' => $data['values'],
                'gender' => $data['gender'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Gender Size Guide. Please try again.'));
        }

        return $genderSizeGuide;
    }

    public function update(GenderSizeGuide $genderSizeGuide, array $data = []): GenderSizeGuide|null
    {

        try {
            $genderSizeGuide->update([
                'type_id' => $data['type_id'],
                'size_on_label' => $data['size_on_label'],
                'values' => $data['values'],
                'gender' => $data['gender'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Gender Size Guide. Please try again.'));
        }

        return $genderSizeGuide;
    }

    public function delete(GenderSizeGuide $genderSizeGuide): GenderSizeGuide|null
    {
        if ($this->deleteById($genderSizeGuide->id)) {
            return $genderSizeGuide;
        }
        throw new GeneralException('There was a problem deleting this Gender Size Guide. Please try again.');
    }
}
