<?php

namespace App\Domains\Product\Services;

use App\Domains\Product\Models\Setting\Material;
use App\Exceptions\GeneralException;
use App\Services\BaseService;

class MaterialService extends BaseService
{
    protected $material;

    public function __construct(Material $material)
    {
        $this->model = $material;
    }

    public function getMaterials()
    {
        return $this->model->oldest('name')->get(['id', 'name', 'value']);
    }

    public function create(array $data = []): Material|null
    {

        try {
            $material = $this->model->create([
                'name' => $data['name'],
                'value' => $data['value'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Material. Please try again.'));
        }


        return $material;
    }

    public function update(Material $material, array $data = []): Material|null
    {

        try {
            $material->update([
                'name' => $data['name'],
                'value' => $data['value'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Material. Please try again.'));
        }


        return $material;
    }

    public function delete(Material $material): Material|null
    {
        if ($this->deleteById($material->id)) {
            return $material;
        }
        throw new GeneralException('There was a problem deleting this Material. Please try again.');
    }
}
