<?php

namespace App\Domains\Product\Services;

use App\Domains\Auth\Models\User;
use App\Domains\Product\Models\Photo;
use App\Domains\Product\Models\Product;
use App\Domains\Product\Models\ProductDetail;
use App\Domains\Product\Models\ProductTypeField;
use App\Domains\Product\Models\ProductVariant;
use App\Domains\Product\Models\Setting\Brand;
use App\Domains\Product\Models\Setting\Material;
use App\Domains\Product\Models\Setting\RecommendedSize;
use App\Domains\Product\Models\Setting\Setting;
use App\Domains\Product\Models\Setting\SizeOnLabel;
use App\Domains\Product\Models\Setting\Variant;
use App\Domains\Product\Models\UniqueTag;
use App\Exceptions\GeneralException;
use App\Services\BaseService;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Http;

class ProductService extends BaseService
{
    /**
     * UserService constructor.
     *
     * @param  User  $product
     */

    protected $product;
    protected $productVariants;
    protected $photo;
    protected $productTypeFields;
    protected $productDetails;
    protected $brand;
    protected $tag;
    protected $userModel;
    protected $material;
    protected $recommendedSize;

    public function __construct(
        Product $product,
        ProductVariant $productVariants,
        Photo $photo,
        ProductTypeField $productTypeFields,
        ProductDetail $productDetails,
        Brand $brand,
        User $user,
        UniqueTag $tag,
        RecommendedSize $recommendedSize,
        Material $material
    )
    {
        $this->model = $product;
        $this->productVariantModel = $productVariants;
        $this->photoModel = $photo;
        $this->productTypeFieldModel = $productTypeFields;
        $this->productDetailModel = $productDetails;
        $this->brand = $brand;
        $this->userModel = $user;
        $this->tag = $tag;
        $this->recommendedSize = $recommendedSize;
        $this->material = $material;
    }

    /**
     * @param  array  $data
     * @return Product
     *
     * @throws GeneralException
     * @throws \Throwable
     */
    public function store(array $data = []): Product
    {

        try {
            if (!$this->brand->where('name', $data['brand_id'])->first())
            {
                $finalBrand = $this->brand->create(['name' => $data['brand_id'], 'shopify_value' => $data['brand_id']]);
                $finalBrand = $finalBrand->id;
            }else{
                $finalBrand = $this->brand->where('name', $data['brand_id'])->first()->id;
            }

            if (!$this->material->where('name', $data['material_id'])->first())
           {
               $finalMaterial = $this->material->create(['name' => $data['material_id'], 'value' => $data['material_id']]);
               $finalMaterial = $finalMaterial->id;
           }else{
               $finalMaterial = $this->material->where('name', $data['material_id'])->first()->id;
           }

           if (!$this->recommendedSize->where('name', $data['recommended_size_id'])->first())
           {
               $finalRecommendedSize = $this->recommendedSize->create(['name' => $data['recommended_size_id'], 'value' => $data['recommended_size_id']]);
               $finalRecommendedSize = $finalRecommendedSize->id;
           }else{
               $finalRecommendedSize = $this->recommendedSize->where('name', $data['recommended_size_id'])->first()->id;
           }

            $product = $this->model->create([
                'type_id' => $data['type_id'],
                'damage_preset' => $data['damage_preset'],
                'reworks' => isset($data['rework']) ? $data['rework'] : null,
                'truesizes' => $data['true_size'],
                'size_on_label' => $data['size_on_label'],
                'gender' => $data['gender'],
                'brand_id' => $finalBrand,
                'recommended_size_id' => $finalRecommendedSize,
                'material_id' => $finalMaterial,
                'embroidered_or_printed' => $data['embroidered_or_printed'],
                'unique_tag' => $data['unique_tag'],
                'stage' => $this->model::STAGE_CREATED,
                'user_id' => $data['user_id'],
		'vcuk'	=> $data['unique_tag']
            ]);

            if(isset($data['variant_name'])) {
                for ($i = 0; $i < count($data['variant_name']); $i++) {
                    if (!empty($data['variant_value'][$i])) {
                        $this->productVariantModel->create([
                            'product_id' => $product->id,
                            'name' => $data['variant_name'][$i],
                            'value' => $data['variant_value'][$i]
                        ]);
                    }
                }
            }

            if(isset($data['type_fields_name']) && !empty($data['type_fields_name']) && !empty($data['type_fields_value']) && !empty($data['type_id']))
            {
                for ($i = 0; $i < count($data['type_fields_name']); $i++) {
                    if (!empty($data['type_fields_value'][$i])) {
                        $this->productTypeFieldModel->create([
                            'product_id' => $product->id,
                            'name' => $data['type_fields_name'][$i],
                            'value' => $data['type_fields_value'][$i],
                            'type_id' => $data['type_fields_id'][$i]
                        ]);
                    }
                }
            }

//            foreach ($data['photos'] as $photo)
//            {
//                $this->photoModel->create([
//                    'product_id' => $product->id,
//                    'url' => $photo,
//                ]);
//            }
            $image_number = 1;
            foreach ($data['photos'] as $photo)
            {
                $photo = json_decode($photo, true);
                if(!empty($photo)) {
                    $rand = $image_number.'-'.$product->unique_tag.'-'.\Str::random('30');
                    $image = \Image::make($photo['data'])->encode('jpg');
                    $path = 'products/'.$rand.'.jpg';
                    \Storage::put($path, $image);

                    $imageMini = \Image::make($photo['data'])->widen(500)->encode('jpg');
                    $pathMini = 'mini/products/'.$rand.'.jpg';
                    \Storage::put($pathMini, $imageMini);

                    $this->photoModel->create([
                        'product_id' => $product->id,
                        'url' => $path,
                    ]);
                }
                $image_number++;
            }

            $this->createProductShopify($product);


        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this product. Please try again.'));
        }



        return $product;
    }


    public function update(Product $product, array $data = []): Product
    {

        try {

            if (!$this->brand->where('name', $data['brand_id'])->first())
            {
                $finalBrand = $this->brand->create(['name' => $data['brand_id'], 'shopify_value' => $data['brand_id']]);
                $finalBrand = $finalBrand->id;
            }else{
                $finalBrand = $this->brand->where('name', $data['brand_id'])->first()->id;
            }

            if (!$this->material->where('name', $data['material_id'])->first())
           {
               $finalMaterial = $this->material->create(['name' => $data['material_id'], 'value' => $data['material_id']]);
               $finalMaterial = $finalMaterial->id;
           }else{
               $finalMaterial = $this->material->where('name', $data['material_id'])->first()->id;
           }

           if (!$this->recommendedSize->where('name', $data['recommended_size_id'])->first())
           {
               $finalRecommendedSize = $this->recommendedSize->create(['name' => $data['recommended_size_id'], 'value' => $data['recommended_size_id']]);
               $finalRecommendedSize = $finalRecommendedSize->id;
           }else{
               $finalRecommendedSize = $this->recommendedSize->where('name', $data['recommended_size_id'])->first()->id;
           }

            $product->update([
                'type_id' => $data['type_id'],
                'brand_id' => $finalBrand,
                'damage_preset' => $data['damage_preset'],
                'gender' => $data['gender'],
                'size_on_label' => $data['size_on_label'],
                'embroidered_or_printed' => $data['embroidered_or_printed'],
                'recommended_size_id' => $finalRecommendedSize,
                'material_id' => $finalMaterial,
            ]);

            $product->photos()->delete();
            $image_number = 1;
            foreach ($data['photos'] as $photo)
            {
                $photo = json_decode($photo, true);
                if(!empty($photo)) {
                    $rand = $image_number.'-'.$product->unique_tag.'-'.\Str::random('30');
                    $image = \Image::make($photo['data'])->encode('jpg');
                    $path = 'products/'.$rand.'.jpg';
                    \Storage::put($path, $image);

                    $imageMini = \Image::make($photo['data'])->widen(500)->encode('jpg');
                    $pathMini = 'mini/products/'.$rand.'.jpg';
                    \Storage::put($pathMini, $imageMini);

                    $this->photoModel->create([
                        'product_id' => $product->id,
                        'url' => $path,
                    ]);
                }
                $image_number++;
            }

            if(isset($data['variant_name'])) {
                $product->productVariants()->delete();
                for ($i = 0; $i < count($data['variant_name']); $i++) {
                    if (!empty($data['variant_value'][$i])) {
                        $this->productVariantModel->create([
                            'product_id' => $product->id,
                            'name' => $data['variant_name'][$i],
                            'value' => $data['variant_value'][$i]
                        ]);
                    }
                }
            }

            if(isset($data['type_fields_name']) && !empty($data['type_fields_name']) && !empty($data['type_fields_value']) && !empty($data['type_id']))
            {
                $product->productTypeFields()->delete();
                for ($i = 0; $i < count($data['type_fields_name']); $i++) {
                    if (!empty($data['type_fields_value'][$i])) {
                        $this->productTypeFieldModel->create([
                            'product_id' => $product->id,
                            'name' => $data['type_fields_name'][$i],
                            'value' => $data['type_fields_value'][$i],
                            'type_id' => $data['type_fields_id'][$i]
                        ]);
                    }
                }
            }

        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem updating this product. Please try again.'));
        }



        return $product;
    }


    public function preCheckProductStore(Product $product, array $data = []): Product
    {

        try {

            if (!$this->brand->where('name', $data['brand_id'])->first())
            {
                $finalBrand = $this->brand->create(['name' => $data['brand_id'], 'shopify_value' => $data['brand_id']]);
                $finalBrand = $finalBrand->id;
            }else{
                $finalBrand = $this->brand->where('name', $data['brand_id'])->first()->id;
            }

            $product->update([
                'type_id' => $data['type_id'],
                'brand_id' => $finalBrand,
                'price' => $data['price'],
                'gender' => $data['gender'],
                'gg' => isset($data['gg']) ? 1 : NULL,
                'stage' => $this->model::STAGE_PRE_CHECK
            ]);

            if(isset($data['detail_name'])) {
                $product->productDetils()->delete();
                for ($i = 0; $i < count($data['detail_name']); $i++) {
                    if (!empty($data['detail_name'][$i])) {
                        $this->productDetailModel->create([
                            'product_id' => $product->id,
                            'name' => $data['detail_name'][$i],
                            'value' => $data['detail_value'][$i]
                        ]);
                    }
                }
            }

            if(isset($data['variant_name'])) {
                $product->productVariants()->delete();
                for ($i = 0; $i < count($data['variant_name']); $i++) {
                    if (!empty($data['variant_value'][$i])) {
                        $this->productVariantModel->create([
                            'product_id' => $product->id,
                            'name' => $data['variant_name'][$i],
                            'value' => $data['variant_value'][$i]
                        ]);
                    }
                }
            }

            if(isset($data['type_fields_name']) && !empty($data['type_fields_name']) && !empty($data['type_fields_value']) && !empty($data['type_id']))
            {
                $product->productTypeFields()->delete();
                for ($i = 0; $i < count($data['type_fields_name']); $i++) {
                    if (!empty($data['type_fields_value'][$i])) {
                        $this->productTypeFieldModel->create([
                            'product_id' => $product->id,
                            'name' => $data['type_fields_name'][$i],
                            'value' => $data['type_fields_value'][$i],
                            'type_id' => $data['type_fields_id'][$i]
                        ]);
                    }
                }
            }

        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem updating this product. Please try again.'));
        }



        return $product;
    }

    public function arrivalCheckSearch(array $data = []): Product|null
    {
        return $this->model
            ->where('stage', Product::STAGE_CREATED)
            ->where('unique_tag', $data['unique_tag'])
            ->first();
    }


    public function getFirstProductForArrivalCheck(): Product|null
    {
        return $this->model
            ->where('stage', $this->model::STAGE_CREATED)
            ->first();
    }

    public function arrivalCheckProductStore(Product $product, array $data = []): Product
    {
        // dd('dfdfd');
        // dd(descriptionFormated($product, Setting::option('shopify_description_format'), $shopify = false));

        try {

            if (!$this->brand->where('name', $data['brand_id'])->first())
            {
                $finalBrand = $this->brand->create(['name' => $data['brand_id'], 'shopify_value' => $data['brand_id']]);
                $finalBrand = $finalBrand->id;
            }else{
                $finalBrand = $this->brand->where('name', $data['brand_id'])->first()->id;
            }

            if (!$this->material->where('name', $data['material_id'])->first())
            {
               $finalMaterial = $this->material->create(['name' => $data['material_id'], 'value' => $data['material_id']]);
               $finalMaterial = $finalMaterial->id;
            }else{
               $finalMaterial = $this->material->where('name', $data['material_id'])->first()->id;
            }

            if (!$this->recommendedSize->where('name', $data['recommended_size_id'])->first())
            {
               $finalRecommendedSize = $this->recommendedSize->create(['name' => $data['recommended_size_id'], 'value' => $data['recommended_size_id']]);
               $finalRecommendedSize = $finalRecommendedSize->id;
            }else{
               $finalRecommendedSize = $this->recommendedSize->where('name', $data['recommended_size_id'])->first()->id;
            }

            $product->update([
                'era' => $data['era'],
                'type_id' => $data['type_id'],
                'brand_id' => $finalBrand,
                'recommended_size_id' => $finalRecommendedSize,
                'material_id' => $finalMaterial,
                'gender' => $data['gender'],
                'price' => $data['price'],
                'damage_preset' => $data['damage_preset'],
                'size_on_label' => $data['size_on_label'],
                'embroidered_or_printed' => $data['embroidered_or_printed'],
                'vcuk' => $data['vcuk'],
                'gg' => isset($data['gg']) ? 1 : NULL,
                'not_asos' => isset($data['not_asos']) ? 1 : NULL,
                'not_depop' => isset($data['not_depop']) ? 1 : NULL,
                'stage' => $this->model::STAGE_ARRIVAL_CHECK
            ]);

            if(isset($data['detail_name'])) {
                $product->productDetils()->delete();
                for ($i = 0; $i < count($data['detail_name']); $i++) {
                    if (!empty($data['detail_name'][$i])) {
                        $this->productDetailModel->create([
                            'product_id' => $product->id,
                            'name' => $data['detail_name'][$i],
                            'value' => $data['detail_value'][$i]
                        ]);
                    }
                }
            }

            $product->productVariants()->delete();
            for ($i = 0; $i < count($data['variant_name']); $i++)
            {
                if (!empty($data['variant_value'][$i])) {
                    $this->productVariantModel->create([
                        'product_id' => $product->id,
                        'name' => $data['variant_name'][$i],
                        'value' => $data['variant_value'][$i]
                    ]);
                }
            }

            if(isset($data['type_fields_name']) && !empty($data['type_fields_name']) && !empty($data['type_fields_value']) && !empty($data['type_id']))
            {
                $product->productTypeFields()->delete();
                for ($i = 0; $i < count($data['type_fields_name']); $i++) {
                    if (!empty($data['type_fields_value'][$i])) {
                        $this->productTypeFieldModel->create([
                            'product_id' => $product->id,
                            'name' => $data['type_fields_name'][$i],
                            'value' => $data['type_fields_value'][$i],
                            'type_id' => $data['type_fields_id'][$i]
                        ]);
                    }
                }
            }

            $this->updateProductShopify($product);

        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem updating this product. Please try again.'));
        }



        return $product;
    }

    public function getFirstProductForUpload(): Product|null
    {
        $product = $this->model
            ->where('stage', $this->model::STAGE_ARRIVAL_CHECK)
            ->first();

        return $product;
    }

    public function checkProductQuantity(Product $product)
    {
        $shopifySlug = json_decode($product->shopify_response);
        if(isset($shopifySlug->product->handle))
        {
            $shopifyProduct = $this->getShopifyProduct($shopifySlug->product->id);
            if(isset($shopifyProduct->product->variants[0]->inventory_quantity) && $shopifyProduct->product->variants[0]->inventory_quantity == 0)
            {
                $product->update(['stage' => $product::STAGE_OUT_OF_STOCK]);
                return true;
            }
        }
        return false;
    }

    public function uploadProductStore(Product $product, array $data = []): Product|null
    {

        try {
            $product->update([
                'depop_link' => isset($data['depop_link']) ? $data['depop_link'] : '',
                'asos_link' => isset($data['asos_link']) ? $data['asos_link'] : NULL,
                'stage' => $this->model::STAGE_UPLOADED
            ]);

            $shopifySlug = json_decode($product->shopify_response);
            if(isset($shopifySlug->product->handle))
            {
                $tagsCollect = [];
                isset($product->gender[0]) ? $tagsCollect[] = $product->gender[0] : NULL;
                ($product->not_depop == 1) ? $tagsCollect[] = 'NOTDEPOP' : NULL;
                ($product->not_asos == 1) ? $tagsCollect[] = 'NOTASOS' : NULL;
                ($product->gg == 1) ? $tagsCollect[] = 'GG': NULL;
                ($product->depop_link) ? $tagsCollect[] = $product->depop_link : NULL;
                ($product->asos_link) ? $tagsCollect[] = $product->asos_link : NULL;

                $client = new \GuzzleHttp\Client();
                $headers = [
                    'headers' => [
                        'x-shopify-access-token' => config('shopify.shopify_access_token'),
                        'content-type' => 'application/json'
                    ],
                    'body' => json_encode([
                        "product" => [
                            "id" => $shopifySlug->product->id,
                            "tags" => $tagsCollect,
                        ]
                    ])
                ];
                $response = $client->request('PUT', config('shopify.shopify_domain').'/admin/api/'.config('shopify.shopify_api_version').'/products/'.$shopifySlug->product->id.'.json', $headers);
                $data = json_decode($response->getBody()->getContents());
            }

        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem updating this product. Please try again.'));
        }


        return $product;
    }


    public function createProductShopify(Product $product): Product|null
    {
        $varaintsCollect = [];

        foreach ($product->productVariants()->limit(1)->get() as $variant)
        {
            $shopifyVariant = Variant::where('value', $variant->value)->value('shopify_value');
            $shopifySizeOnLabel = SizeOnLabel::where('name', $product->size_on_label)->value('shopify_value');

            $varaintsCollect[] = [
                'option1' => (isset($shopifySizeOnLabel) ? $shopifySizeOnLabel : $product->size_on_label),
                'option2' => (isset($shopifyVariant) ? $shopifyVariant : $variant->value),
                'price' => $product->price,
                'sku' => '',
                'inventory_management' => "shopify",
                'inventory_quantity' => 0
            ];
        }

        $varaintsSumCollect = [];
        foreach ($product->productVariants()->limit(1)->get() as $variant)
        {
            $shopifyVariant = Variant::where('value', $variant->value)->value('shopify_value');
            $varaintsSumCollect[] = isset($shopifyVariant) ? $shopifyVariant : $variant->value;
        }

        $photosCollect = [];
        foreach ($product->photos as $photo)
        {
            $photosCollect[] = ["src" => \Storage::url($photo->url)];
        }

        $tagsCollect = [];
        isset($product->gender[0]) ? $tagsCollect[] = $product->gender[0] : NULL;
        ($product->not_depop == 1) ? $tagsCollect[] = 'NOTDEPOP' : NULL;
        ($product->not_asos == 1) ? $tagsCollect[] = 'NOTASOS' : NULL;
        ($product->gg == 1) ? $tagsCollect[] = 'GG': NULL;

        if($product->reworks){
            $s_title = descriptionFormated($product, Setting::option('rework_shopify_title_format'), $shopify = false, $allow_br = false);
            $s_description = descriptionFormated($product, Setting::option('rework_shopify_description_format'), $shopify = false);
            $size_of_product = $product->truesizes;
        }else{
            $s_title = descriptionFormated($product, Setting::option('shopify_title_format'), $shopify = false, $allow_br = false);
            $s_description = descriptionFormated($product, Setting::option('shopify_description_format'), $shopify = false);
            $size_of_product = $product->size_on_label;
        }

        // Created new array and set primary color entity in it
        $variantsArray[] = $varaintsCollect[0];
        $variantsArray[0]['option1'] = $size_of_product;

        $client = new \GuzzleHttp\Client();
        $headers = [
            'headers' => [
                'x-shopify-access-token' => config('shopify.shopify_access_token'),
                'content-type' => 'application/json'
            ],
            'body' => json_encode([
                "product" => [
                    "title" => $s_title,
                    "body_html" => $s_description,
                    "vendor" => isset($product->brand->shopify_value) ? $product->brand->shopify_value : NULL,
                    "product_type" => isset($product->type->shopify_value) ? $product->type->shopify_value : NULL,
                    "variants" => $variantsArray,
                    "options" => [
                        ["name" => "Size", "values" => [$size_of_product]],
                        ["name" => "Color", "values" => $varaintsSumCollect],
                    ],
                    "images" => $photosCollect,
                    "tags" => $tagsCollect,
                ]
            ])
        ];
        $response = $client->request('POST', config('shopify.shopify_domain').'/admin/api/'.config('shopify.shopify_api_version').'/products.json',$headers);
        $data = json_decode($response->getBody()->getContents());
        $product->update([
            'shopify_response' => json_encode($data)
        ]);

        return $product;
    }

    public function updateProductShopify(Product $product): Product|null
    {
        $varaintsCollect = [];

        if (empty($product->shopify_response)){

            return null;

        }
        $productResponse = json_decode($product->shopify_response);
        $product_id = $productResponse->product->id;
        $variants = $productResponse->product->variants;

        $this->_deleteVariants($product_id, $variants);

        foreach ($product->productVariants()->get() as $variant)
        {
            $shopifyVariant = Variant::where('value', $variant->value)->value('shopify_value');
            $shopifySizeOnLabel = SizeOnLabel::where('name', $product->size_on_label)->value('shopify_value');

            $variantsCollect[] = [
                'option1' => (isset($shopifySizeOnLabel) ? $shopifySizeOnLabel : $product->size_on_label),
                'option2' => (isset($shopifyVariant) ? $shopifyVariant : $variant->value),
                'price' => $product->price,
                'sku' => '',
                'inventory_management' => "shopify",
                'inventory_quantity' => 1
            ];
        }

        $varaintsSumCollect = [];
        foreach ($product->productVariants()->get() as $variant)
        {
            $shopifyVariant = Variant::where('value', $variant->value)->value('shopify_value');
            $varaintsSumCollect[] = isset($shopifyVariant) ? $shopifyVariant : $variant->value;
        }

        $photosCollect = [];
        foreach ($product->photos as $photo)
        {
            $photosCollect[] = ["src" => \Storage::url($photo->url)];
        }

        $tagsCollect = [];
        isset($product->gender[0]) ? $tagsCollect[] = $product->gender[0] : NULL;
        ($product->not_depop == 1) ? $tagsCollect[] = 'NOTDEPOP' : NULL;
        ($product->not_asos == 1) ? $tagsCollect[] = 'NOTASOS' : NULL;
        ($product->gg == 1) ? $tagsCollect[] = 'GG': NULL;

        isset($product->depop_link) ? $tagsCollect[] = $product->depop_link : NULL;
        isset($product->asos_link) ? $tagsCollect[] = $product->asos_link : NULL;


        $size_of_product = "";
        if($product->reworks){
            $s_title = descriptionFormated($product, Setting::option('rework_shopify_title_format'), $shopify = false, $allow_br = false);
            $s_description = descriptionFormated($product, Setting::option('rework_shopify_description_format'), $shopify = false);
            $size_of_product = $product->truesizes;
        }else{
            $s_title = descriptionFormated($product, Setting::option('shopify_title_format'), $shopify = false, $allow_br = false);
            $s_description = descriptionFormated($product, Setting::option('shopify_description_format'), $shopify = false);
            $size_of_product = $product->size_on_label;
        }

        // Created new array and set primary color entity in it
        $variantsArray[] = $variantsCollect[0];
        $variantsArray[0]['option1'] = $size_of_product;
        $client = new \GuzzleHttp\Client();
        $headers = [
            'headers' => [
                'x-shopify-access-token' => config('shopify.shopify_access_token'),
                'content-type' => 'application/json'
            ],
            'body' => json_encode([
                "product" => [
                    "title" => $s_title,
                    "body_html" => $s_description,
                    "vendor" => isset($product->brand->shopify_value) ? $product->brand->shopify_value : NULL,
                    "product_type" => isset($product->type->shopify_value) ? $product->type->shopify_value : NULL,
                    "published_scope" => "global",
                    "published" => true,
                    "variants" => $variantsArray,
                    "options" => [
                        ["name" => "Size", "values" => [$size_of_product]],
                        ["name" => "Color", "values" => $varaintsSumCollect],
                    ],
                    "images" => $photosCollect,
                    "tags" => $tagsCollect,
                ]
            ])
        ];
        $response = $client->request('PUT', config('shopify.shopify_domain').'/admin/api/'.config('shopify.shopify_api_version').'/products/'. $product_id . '.json',$headers);
        $data = json_decode($response->getBody()->getContents());
        $product->update([
            'shopify_response' => json_encode($data)
        ]);

        return $product;

    }

    private function _deleteVariants($product_id, $variants)
    {
        $client = new \GuzzleHttp\Client();
        $headers = [
            'headers' => [
                'x-shopify-access-token' => config('shopify.shopify_access_token'),
                'content-type' => 'application/json'
            ],
        ];
        foreach ($variants as $variant)
        {
            $response = $client->request('DELETE', config('shopify.shopify_domain').'/admin/api/'.config('shopify.shopify_api_version').'/products/'. $product_id . '/variants/'. $variant->id .'.json',$headers);
        }
    }

    public function getShopifyProduct($id)
    {
        $response = Http::withHeaders([
            'x-shopify-access-token' => config('shopify.shopify_access_token'),
            'content-type' => 'application/json'
        ])->get(config('shopify.shopify_domain').'/admin/api/'.config('shopify.shopify_api_version').'/products/'.$id.'.json');

//        $client = new \GuzzleHttp\Client();
//        $response = $client->request('GET', config('shopify.shopify_domain').'/admin/asapi/'.config('shopify.shopify_api_version').'/products/'.$id.'.json', [
//            'headers' => [
//                'x-shopify-access-token' => config('shopify.shopify_access_token'),
//                'content-type' => 'application/json'
//            ]
//        ]);

        return $data = json_decode($response->getBody()->getContents());
    }

    public function storePhotos(array $data = [])
    {
        foreach ($data['photos'] as $photo)
        {
            if(!empty($photo)) {
                $rand = \Str::random('40');
                $image = \Image::make($photo)->encode('jpg');
                $path = 'products/'.$rand.'.jpg';
                \Storage::put($path, $image);

                $imageMini = \Image::make($photo)->widen(500)->encode('jpg');
                $pathMini = 'mini/products/'.$rand.'.jpg';
                \Storage::put($pathMini, $imageMini);

                echo $path;
            }
        }
    }

    public function delete(Product $product, array $data = []): Product|null
    {
        if ($product->delete())
        {
            return $product;
        }

        throw new GeneralException(__('There was a problem deleting this product. Please try again.'));
    }

    public function restore(Product $product): Product|null
    {
        if ($product->restore())
        {
            return $product;
        }
        throw new GeneralException(__('There was a problem restoring this product. Please try again.'));
    }

    /**
     * @param $existing_tag
     * @param $assign_new
     * @return string
     */
    public function _generateTag($existing_tag, $assign_new = false)
    {
        $number = explode('-', $existing_tag);

        if($assign_new)
            $number[0] = (int)$number[0] + 1;

        if(array_key_exists(1, $number)) {
            if($assign_new)
                $tag_dec = str_pad('1', 2, '0', STR_PAD_LEFT);
            else if($number[1] < 10) {
                $tag_dec = (int)$number[1] + 1;
                $tag_dec = str_pad($tag_dec, 2, '0', STR_PAD_LEFT);
            } else {
                $number[0] = (int)$number[0] + 1;
                $tag_dec = str_pad('1', 2, '0', STR_PAD_LEFT);
            }
        }
        else
            $tag_dec = str_pad('1', 2, '0', STR_PAD_LEFT);

        return $number[0] . '-' . $tag_dec;
    }

    /**
     * @return string
     */
    public function getTag($next_tag = false)
    {
        $user = auth()->user();
        $tag = $user->tag;

        $tagArray = explode('-', $tag);

        if((int)$tagArray[1] < 10) {
            $tagArray[1] = (int)$tagArray[1] + 1;
            $tagArray[1] = str_pad($tagArray[1], 2, '0', STR_PAD_LEFT);
            $tagArray[0] = str_pad($tagArray[0], 4, '0', STR_PAD_LEFT);
            $newTag = $tagArray[0].'-'.$tagArray[1];
        }
        else
        {
            $highestTag = User::orderBy('tag', 'desc')->value('tag');
            $highestTagArray = explode('-', $highestTag);
            $highestTagArray[0] = (int)$highestTagArray[0] + 1;
            $highestTagArray[0] = str_pad($highestTagArray[0], 4, '0', STR_PAD_LEFT);
            $newTag = $highestTagArray[0].'-'.'01';

        }
        $user->tag = $newTag;

        $user->save();

        return $newTag;
        
        // $user = auth()->user();
        // $tag = $user->tag;
        // if($next_tag)
        //     $tag = $this->_generateTag($tag);

        // if($tag) {
        //     if (count($product = $this->model->where('unique_tag', $tag)->get()) > 0) {
        //         while ($product = $this->model->where('unique_tag', $tag)->first())
        //             $tag = $this->_generateTag($product->unique_tag);

        //         $user->tag = $tag;
        //         $user->save();
        //     }
        //     if(count($this->userModel->where('tag', $tag)->get()->except(auth()->id())) > 0) {
        //         while (count($this->userModel->where('tag', $tag)->get()->except(auth()->id())) > 0)
        //             $tag = $this->_generateTag($tag, true);

        //         $user->tag = $tag;
        //         $user->save();
        //     }
        //     if(!count($product = $this->model->where('unique_tag', $tag)->get()) > 0 &&
        //      !count($this->userModel->where('tag', $tag)->get()->except(auth()->id())) > 0) {
        //         $user->tag = $tag;
        //         $user->save();
        //     }
        // } else {
        //     $existing_users = $this->userModel->all()->except($user->id);

        //     if(count($existing_users) > 0) {
        //         $tag = $existing_users->last()->tag;
        //     } else {
        //         $tag = $this->tag->first()->value ?? '1400';
        //     }

        //     if (count($product = $this->model->where('unique_tag', $tag)->get()) > 0) {
        //         while ($product = $this->model->where('unique_tag', $tag)->first())
        //             $tag = $this->_generateTag($product->unique_tag);

        //     }

        //     $user->tag = $this->_generateTag($tag, true);
        //     $user->save();
        // }

        // return $tag;
    }
}
