<?php

namespace App\Domains\Product\Services;

use App\Domains\Product\Models\Setting\RecommendedSize;
use App\Exceptions\GeneralException;
use App\Services\BaseService;

class RecommendedSizeService extends BaseService
{
    protected $recommended_size;

    public function __construct(RecommendedSize $recommended_size)
    {
        $this->model = $recommended_size;
    }

    public function getRecommendedSizes()
    {
        return $this->model->oldest('name')->get(['id', 'name', 'value']);
    }

    public function create(array $data = []): RecommendedSize|null
    {

        try {
            $recommended_size = $this->model->create([
                'name' => $data['name'],
                'value' => $data['value'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Recommended Size. Please try again.'));
        }


        return $recommended_size;
    }

    public function update(RecommendedSize $recommended_size, array $data = []): RecommendedSize|null
    {

        try {
            $recommended_size->update([
                'name' => $data['name'],
                'value' => $data['value'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Recommended Size. Please try again.'));
        }


        return $recommended_size;
    }

    public function delete(RecommendedSize $recommended_size): RecommendedSize|null
    {
        if ($this->deleteById($recommended_size->id)) {
            return $recommended_size;
        }
        throw new GeneralException('There was a problem deleting this Recommended Size. Please try again.');
    }
}
