<?php

namespace App\Domains\Product\Services;

use App\Domains\Product\Models\Setting\Rework;
use App\Exceptions\GeneralException;
use App\Services\BaseService;

class ReworkService extends BaseService
{
    protected $rework;

    public function __construct(Rework $rework)
    {
        $this->model = $rework;
    }

    public function getRework()
    {
        return $this->model->oldest('name')->get(['id', 'name']);
    }

    public function create(array $data = []): Rework|null
    {

        try {
            $rework = $this->model->create([
                'name' => $data['name'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Damage Preset. Please try again.'));
        }

        return $rework;
    }

    public function update(Rework $rework, array $data = []): Rework|null
    {

        try {
            $rework->update([
                'name' => $data['name'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Damage Preset. Please try again.'));
        }

        return $rework;
    }

    public function delete(Rework $rework): Rework|null
    {
        if ($this->deleteById($rework->id)) {
            return $rework;
        }
        throw new GeneralException('There was a problem deleting this Damage Preset. Please try again.');
    }
}
