<?php

namespace App\Domains\Product\Services;

use App\Domains\Product\Models\Setting\SizeOnLabel;
use App\Exceptions\GeneralException;
use App\Services\BaseService;
use Illuminate\Support\Facades\DB;

class SizeOnLabelService extends BaseService
{
    protected $sizeOnLabel;

    public function __construct(SizeOnLabel $sizeOnLabel)
    {
        $this->model = $sizeOnLabel;
    }

    public function getSizeOnLabel()
    {
        return $this->model->get(['id', 'name', 'shopify_value']);
    }


    public function create(array $data = []): SizeOnLabel|null
    {

        try {
            $sizeOnLabel = $this->model->create([
                'name' => $data['name'],
                'shopify_value' => $data['shopify_value'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Size on Label. Please try again.'));
        }

        return $sizeOnLabel;
    }

    public function update(SizeOnLabel $sizeOnLabel, array $data = []): SizeOnLabel|null
    {

        try {
            $sizeOnLabel->update([
                'name' => $data['name'],
                'shopify_value' => $data['shopify_value'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Size on Label. Please try again.'));
        }

        return $sizeOnLabel;
    }

    public function delete(SizeOnLabel $sizeOnLabel): SizeOnLabel|null
    {
        if ($this->deleteById($sizeOnLabel->id)) {
            return $sizeOnLabel;
        }
        throw new GeneralException('There was a problem deleting this Size on Label. Please try again.');
    }
}
