<?php

namespace App\Domains\Product\Services;

use App\Domains\Auth\Models\User;
use App\Domains\Product\Models\Product;
use App\Domains\Product\Models\Setting\Brand;
use App\Domains\Product\Models\UniqueTag;
use App\Exceptions\GeneralException;
use App\Services\BaseService;
use Exception;
use Illuminate\Contracts\Container\BindingResolutionException;

class TagService extends BaseService
{
    protected $userModel;
    protected $productModel;

    /**
     * @param UniqueTag $tag
     * @param User $user
     * @param Product $product
     */
    public function __construct(
        UniqueTag $tag,
        User $user,
        Product $product
    )
    {
        $this->model = $tag;
        $this->userModel = $user;
        $this->productModel = $product;
    }

    /**
     * @return mixed
     */
    public function getTag()
    {
        return $this->model->first();
    }

    /**
     * @param array $data
     * @return mixed
     * @throws GeneralException
     */
    public function create(array $data = []): mixed
    {

        try {
            $tag = $this->model->create([
                'value' => $data['value'],
                'updated' => 1,
            ]);
            $this->_updateUserTag($data['value']);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Tag. Please try again.'));
        }


        return $tag;
    }

    /**
     * @throws GeneralException
     */
    public function update(UniqueTag $tag, array $data = []): UniqueTag|null
    {
        try {
            $tag->update([
                'value' => $data['value'],
            ]);
            $this->_updateUserTag($data['value']);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Brand. Please try again.'));
        }


        return $tag;
    }

    /**
     * @throws GeneralException
     */
    public function delete(UniqueTag $tag): UniqueTag|null
    {
        if ($this->deleteById($tag->id)) {
            return $tag;
        }
        throw new GeneralException('There was a problem deleting this Brand. Please try again.');
    }

    /**
     * @param $tag
     * @return void
     * @throws BindingResolutionException
     */
    private function _updateUserTag($tag)
    {
        $users = $this->userModel->all();
        foreach ($users as $key=>$user)
        {
            $newTag = app()->make(ProductService::class)->_generateTag($tag + $key, true);
            while ($this->userModel->where('tag', $newTag)->first() ||
                $this->productModel->where('unique_tag', $newTag)->first())
            {
                $newTag = app()->make(ProductService::class)->_generateTag($newTag, true);
            }
            $user->tag = $newTag;
            $user->save();
        }
    }
}
