<?php

namespace App\Domains\Product\Services;

use App\Domains\Product\Models\ProductTypeField;
use App\Domains\Product\Models\Setting\Type;
use App\Domains\Product\Models\Setting\TypeField;
use App\Exceptions\GeneralException;
use App\Services\BaseService;
use Illuminate\Support\Facades\DB;

class TypeService extends BaseService
{
    protected $type;
    protected $typeField;
    protected $productTypeField;

    public function __construct(Type $type, TypeField $typeField, ProductTypeField $productTypeField)
    {
        $this->model = $type;
        $this->fieldModel = $typeField;
        $this->productTypeFieldModel = $productTypeField;
    }

    public function getTypes()
    {
        return $this->model->oldest('name')->get(['id', 'name', 'shopify_value']);
    }

    public function getTypeFields()
    {
        return $this->fieldModel->get(['id', 'type_id', 'name']);
    }

    public function getProductTypeFields($product_id)
    {
       return $this->productTypeFieldModel->where('product_id', $product_id)->get(['id', 'name', 'type_id', 'value']);
    }

    public function create(array $data = []): Type|null
    {

        try {
            $type = $this->model->create([
                'name' => $data['name'],
                'shopify_value' => $data['shopify_value'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Type. Please try again.'));
        }

        return $type;
    }

    public function update(Type $type, array $data = []): Type|null
    {

        try {
            $type->update([
                'name' => $data['name'],
                'shopify_value' => $data['shopify_value'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Type. Please try again.'));
        }

        return $type;
    }

    public function delete(Type $type): Type|null
    {
        if ($this->deleteById($type->id)) {
            return $type;
        }
        throw new GeneralException('There was a problem deleting this Type. Please try again.');
    }



    public function fieldCreate(array $data = []): TypeField|null
    {

        try {
            $typeField = $this->fieldModel->create([
                'name' => $data['name'],
                'type_id' => $data['type_id'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Type Field. Please try again.'));
        }

        return $typeField;
    }

    public function fieldUpdate(TypeField $typeField, array $data = []): TypeField|null
    {

        try {
            $typeField->update([
                'name' => $data['name'],
                'type_id' => $data['type_id'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Type Field. Please try again.'));
        }

        return $typeField;
    }

    public function FieldDelete(TypeField $typeField, array $data = []): TypeField|null
    {
        if ($typeField->delete()) {
            return $typeField;
        }
        throw new GeneralException('There was a problem deleting this Type. Please try again.');
    }
}
