<?php

namespace App\Domains\Product\Services;

use App\Domains\Product\Models\ProductVariant;
use App\Domains\Product\Models\Setting\Variant;
use App\Exceptions\GeneralException;
use App\Services\BaseService;
use Illuminate\Support\Facades\DB;

class VariantService extends BaseService
{
    protected $variant;
    protected $productVariant;

    public function __construct(Variant $variant, ProductVariant $productVariant)
    {
        $this->model = $variant;
        $this->productVariantModel = $productVariant;
    }

    public function getVariants()
    {
        $variantGroups = $this->model->select('name')->groupBy('name')->get();

        $collect = collect();
        foreach ($variantGroups as $variantGroup) {
            $sub_variants = $this->model->where('name', $variantGroup->name)->orderBy('value', 'asc')->get();
            $sub_collect = [];
            foreach ($sub_variants as $sub_variant) {
                $sub_collect[] = $sub_variant->value;
            }
            $collect->put($variantGroup->name, $sub_collect);
        }
        return $collect->all();
    }

    public function getProductVariants($product_id)
    {
        $variantGroups = $this->productVariantModel->where('product_id',
            $product_id)->select('name')->groupBy('name')->get();

        $collect = collect();
        foreach ($variantGroups as $variantGroup) {
            $sub_variants = $this->productVariantModel->where('product_id', $product_id)->where('name',
                $variantGroup->name)->orderBy('value', 'asc')->get();
            $sub_collect = [];
            foreach ($sub_variants as $sub_variant) {
                $sub_collect[] = $sub_variant->value;
            }
            $collect->put($variantGroup->name, $sub_collect);
        }

        return $collect->all();
    }

    public function getRawVariants()
    {
        return $this->model->orderBy('value', 'asc')->orderBy('value', 'asc')->get();
    }

    public function create(array $data = []): Variant|null
    {

        try {
            $variant = $this->model->create([
                'name' => $data['name'],
                'value' => $data['value'],
                'shopify_value' => $data['shopify_value'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Variant. Please try again.'));
        }

        return $variant;
    }

    public function update(Variant $variant, array $data = []): Variant|null
    {

        try {
            $variant->update([
                'name' => $data['name'],
                'value' => $data['value'],
                'shopify_value' => $data['shopify_value'],
            ]);
        } catch (Exception $e) {

            throw new GeneralException(__('There was a problem creating this Variant. Please try again.'));
        }

        return $variant;
    }

    public function delete(Variant $variant): Variant|null
    {
        if ($this->deleteById($variant->id)) {
            return $variant;
        }
        throw new GeneralException('There was a problem deleting this Variant. Please try again.');
    }

}
