<?php

use Carbon\Carbon;
use \App\Domains\Product\Models\Product;

if (! function_exists('appName')) {
    /**
     * Helper to grab the application name.
     *
     * @return mixed
     */
    function appName()
    {
        return config('app.name', 'Laravel Boilerplate');
    }
}

if (! function_exists('carbon')) {
    /**
     * Create a new Carbon instance from a time.
     *
     * @param $time
     * @return Carbon
     *
     * @throws Exception
     */
    function carbon($time)
    {
        return new Carbon($time);
    }
}

if (! function_exists('homeRoute')) {
    /**
     * Return the route to the "home" page depending on authentication/authorization status.
     *
     * @return string
     */
    function homeRoute()
    {
        if (auth()->check()) {
            if (auth()->user()->isAdmin()) {
                return 'admin.dashboard';
            }

            if (auth()->user()->isUser()) {
                return 'frontend.user.dashboard';
            }
        }

        return 'frontend.index';
    }
}

if (! function_exists('priceRound')) {
    /**
     * Access the priceRound helper.
     */
    function priceRound($value)
    {
        return number_format($value, 2);
    }
}

if (! function_exists('descriptionKeys')) {
    /**
     * Access the priceRound helper.
     */
    function descriptionKeys($product = NULL, $shopify = false)
    {

        if ($product)
        {

            $productTypesString = [];
            foreach ($product->productTypeFields as $productTypeField)
            {
                $productTypesString[] = $productTypeField->name.' '.$productTypeField->value.'"';
            }

            $productVariantsString = [];
            $i = 1;
            foreach ($product->productVariants as $productVaraint)
            {
                $productVariantsString[] = $productVaraint->name.' '.$i++.': '.$productVaraint->value;
            }


            $color_1 = isset($product->productVariants[0]) ? $product->productVariants[0] : NULL;
            $color_2 = isset($product->productVariants[1]) ? $product->productVariants[1] : NULL;

            $both_colors = [];
            foreach ($product->productVariants as $productVaraint)
            {
                $both_color[] = $productVaraint->value;
            }
            $both_colors = implode(', ', $both_color);

            $productDetailsString = [];
            foreach ($product->productDetils as $productDetail)
            {
                (!empty($productDetail->value)) ? $productDetailsString[] = $productDetail->value : '';
            }

            $unc_size = isset($product->size_on_label[0]) ? $product->size_on_label[0] : '';
            $unc_gender = isset($product->gender[0]) ? $product->gender[0] : '';
            $unique_string_code = 'Ref-'.strtoupper($unc_size.$unc_gender.($product->id*14).'-'.$product->unique_tag);
        }


        if ($shopify)
        {
            $sizeOnLabel = $product->size_on_label ? \App\Domains\Product\Models\Setting\SizeOnLabel::where('name', $product->size_on_label)->value('shopify_value') : NULL;
            $brand = $product->brand_id ? \App\Domains\Product\Models\Setting\Brand::withTrashed()->where('id', $product->brand_id)->value('shopify_value') : NULL;
            $type = $product->type_id ? \App\Domains\Product\Models\Setting\Type::withTrashed()->where('id', $product->type_id)->value('shopify_value') : NULL;
        }else{
            $sizeOnLabel = $product->size_on_label ?? NULL;
            $brand = isset($product->brand->name) ? $product->brand->name : NULL;
            $type = isset($product->type->name) ? $product->type->name : NULL;
        }

        
        return [
            '_PRODUCT_TYPE_' => isset($type) ? $type : NULL,
            '_TYPE_ATTRIBUTE_LIST_' => isset($productTypesString) ? implode(PHP_EOL, $productTypesString) : NULL,
            '_BUNDLE_DEALS_' => isset($product->type->bundleDeal) ? $product->type->bundleDeal->value : NULL,
            '_DAMAGE_PRESET_' => $product->damage_preset ?? NULL,
            '_TRUE_SIZE_' => $product->truesizes ?? NULL,
            '_REWORK_' => $product->reworks ?? NULL,
            '_BRAND_' => isset($brand) ? $brand : NULL,
            '_EMBROIDERED_PRINTED_' => !empty($product->embroidered_or_printed) ? $product->embroidered_or_printed.' ' : NULL,
            '_SIZE_' => isset($sizeOnLabel) ? $sizeOnLabel : NULL,
            '_PRICE_' => $product->price_formated ?? NULL,
            '_VCUK_' => $product->vcuk ?? NULL,
            '_ERA_' => $product->era ?? NULL,
            '_GENDER_' => $product->gender ?? NULL,
            '_UNIQUE_STRING_CODE_' => isset($unique_string_code) ? $unique_string_code : NULL,
//            '_COLORS_' => isset($productVariantsString) ? implode(PHP_EOL, $productVariantsString) : NULL,
            '_COLOR_1_' => isset($color_1) ? $color_1->value : NULL,
            '_COLOR_2_' => isset($color_2) ? $color_2->value : NULL,
            '_COLORS_ALL_' => isset($both_colors) ? $both_colors : NULL,
            '_DETAILS_' => isset($productDetailsString) ? implode(' ', $productDetailsString) : NULL,
        ];
    }
}


if (! function_exists('descriptionFormated')) {
    /**
     * Access the descriptionFormated helper.
     */
    function descriptionFormated($product, $description, $shopify = false, $allow_br = true)
    {
        $array = descriptionKeys($product, $shopify);

        $search = array_keys($array);
        $replace = array_values($array);

        $description = \Str::replace($search, $replace, $description);
        
        if ($allow_br)
        {
            $description = \Str::replace(PHP_EOL, '<br>', $description);
        }else{
            $description = \Str::replace(PHP_EOL, ' ', $description);
        }

        return $description;
    }
}
