@inject('model', '\App\Domains\Product\Models\Product')
@inject('productVariantModel', '\App\Domains\Product\Models\ProductVariant')

@extends('backend.layouts.app')

@section('title', __('Checks'))

@section('content')

    @include('backend.product.includes.search-product-by-unique-tag')

    <span id="ajax_call_alerts"></span>
    <x-forms.post :action="route('admin.product.arrival_check.product.store', $product->id)" id="arrivalCheckForm"
                  enctype="multipart/form-data">
        @method('PUT')
        <x-backend.card>
            <x-slot name="header">
                @lang('Checks')
            </x-slot>

            <x-slot name="headerActions">
                <a  href="{{route('admin.product.edit', $product)}}"
                    class="btn btn-primary">
                    Edit
                </a>
                <x-utils.link class="card-header-action" :href="route('admin.product.arrival_check')"
                              :text="__('Cancel')"/>
            </x-slot>

            <x-slot name="body">
                <div class="row">
                    <div class="col-lg-5">
                        <img class="w-100"
                             src="{{$product->photos->first() ? Storage::url('mini/'.$product->photos->first()->url) : ''}}">

                        <div class="form-group row mt-3">
                            <div class="col-md-4">
                                <div class="form-check form-control pl-4">
                                    <input class="form-check-input" @if($product->gg == 1) checked @endif name="gg"
                                           type="checkbox" value="1" id="flexCheckDefault">
                                    <label class="form-check-label text-dark" for="flexCheckDefault">
                                        <b>GG</b>
                                    </label>
                                </div>
                            </div>
                            <div class="col-md-4">
                                <div class="form-check form-control pl-4">
                                    <input class="form-check-input" @if($product->not_asos == 1) checked
                                           @endif name="not_asos" type="checkbox" value="1" id="not_asos">
                                    <label class="form-check-label text-dark" for="not_asos">
                                        <b>Not Asos</b>
                                    </label>
                                </div>
                            </div>
                            <div class="col-md-4">
                                <div class="form-check form-control pl-4">
                                    <input class="form-check-input" @if($product->not_depop == 1) checked
                                           @endif name="not_depop" type="checkbox" value="1" id="not_depop">
                                    <label class="form-check-label text-dark" for="not_depop">
                                        <b>Not Depop</b>
                                    </label>
                                </div>
                            </div>
                        </div><!--form-group-->

                        <div class="rework_section">
                            <div class="form-group row">
                                <label for="brand_id">@lang('Rework')</label>
                                <input type="checkbox" id="rework_check" name="rework_check" @if($product->reworks != null) checked @endif >
                            </div>
                        </div>


                    </div>
                    <div class="col-lg-7">
                        <div class="form-group row">
                            <div class="col-md-4"></div>
                            <div class="col-md-8">
                                @if(isset($product->barcode) && !empty($product->barcode))
                                    @php echo '<a id="updateBarcodeData" href="data:image/png;base64,' . DNS1D::getBarcodePNG("$product->barcode", "C128",3,33) . '" class="btn btn-success" download="barcode.png"> Download Barcode  </a>'; @endphp
                                    <input type="hidden" id="product_id" name="product_id" value="{{ $product->id }}">
                                    <input type="hidden" id="barcode" name="barcode" value="{{ $product->barcode }}">
                                @endif
                            </div>
                        </div>
                        <div class="bggray-box">
                            <div class="form-group row">
                                <label for="barcode" class="col-md-4 col-form-label">@lang('Barcode')</label>
                                <div class="col-md-8">
                                    @if(isset($product->barcode) && !empty($product->barcode))
                                        @php echo '<img src="data:image/png;base64,' . DNS1D::getBarcodePNG("$product->barcode", "C128",2,33) . '" alt="barcode"   />'; @endphp
                                    @else
                                        No Barcode Found.
                                    @endif
                                </div>

                            </div>
                            <div class="form-group row">
                                <label for="era" class="col-md-4 col-form-label">@lang('Era')</label>

                                <div class="col-md-8">
                                    <select class="form-control" name="era" id="era" required>
                                        @foreach($eras as $era)
                                            @if($product->era)
                                                <option value="{{$era->era}}"
                                                        @if($era->era == $product->era) selected @endif
                                                >
                                                    {{$era->era}}
                                                </option>
                                            @else
                                                <option value="{{$era->era}}"
                                                        @if(\Str::contains($era->era, '90'))
                                                            selected
                                                        @endif
                                                >
                                                    {{$era->era}}
                                                </option>
                                            @endif
                                        @endforeach
                                    </select>
                                </div>
                            </div><!--form-group-->


                            @for($i = 1; $i <= 4; $i++)
                                @php
                                      $detailValue = $productDetails->where('name', 'Detail '.$i)->first();
                                @endphp
                                <div class="form-group row">
                                    <label for="detail_field_{{$i}}"
                                           class="col-md-4 col-form-label">@lang('Detail '.$i)</label>
                                    @if($i == 1)
                                    <div class="col-md-8">
                                        <input type="text" name="detail_value[]"
                                               value="{{isset($detailValue) ? $detailValue->value : ''}}"
                                               id="detail_field_{{$i}}" placeholder="{{'Detail '.$i}}"
                                               class="form-control detailKeySystem" tabindex="-1">
                                        <input type="hidden" name="detail_name[]" value="{{'Detail '.$i}}">
                                    </div>
                                    @else
                                    <div class="col-md-4">
                                        <input type="text"
                                               id="detail_field_name_{{$i}}" onkeyup="DetailKeySystem('{{$i}}')"
                                               class="form-control" autocomplete="off">

                                        <input type="hidden" name="detail_name[]" value="{{'Detail '.$i}}">
                                    </div>
                                    <div class="col-md-4">
                                        <input type="text" name="detail_value[]"
                                               value="{{isset($detailValue) ? $detailValue->value : ''}}"
                                               id="detail_field_{{$i}}" placeholder="{{'Detail '.$i}}"
                                               class="form-control detailKeySystem" tabindex="-1">
                                    </div>
                                    @endif
                                </div><!--form-group-->
                            @endfor


                            <!-- <div class="form-group row">
                                @php
                                    $detailFourValue = $productDetails->where('name', 'Detail '.$i)->first();
                                @endphp
                                <label for="type_field_detail4" class="col-md-4 col-form-label">@lang('Detail '.$i)</label>
                                <div class="col-md-8">
                                    <input type="hidden" name="detail_name[]" value="{{'Detail '.$i}}">
                                        <select id="type_field_detail4" name="detail_value[]" class="form-control">
                                        @foreach($details as $detail)
                                            <option value="{{$detail->value}}"
                                            @if(isset($detailFourValue))
                                                @if($detailFourValue->value == $detail->value)
                                                    selected=""
                                                @endif
                                            @endif
                                            >{{$detail->value}}</option>
                                        @endforeach
                                        </select>
                                </div>
                            </div> -->
                            <!--form-group-->


                            <div class="form-group row">
                                <label for="price" class="col-md-4 col-form-label">@lang('Price')</label>

                                <div class="col-md-8">
                                    <input type="text" name="price" id="price"
                                           value="{{(!empty($product->price) && $product->price != 0) ? $product->price : '' }}"
                                           class="form-control"
                                           placeholder="{{ __('Price') }}" required />
                                </div>
                            </div><!--form-group-->
                        </div>


                        <div class="form-group row">
                            <label for="vcuk" class="col-md-4 col-form-label">@lang('VCUK')</label>

                            <div class="col-md-8">
                                <input type="text" name="vcuk" id="vcuk" value="{{$product->vcuk ?? $product->unique_tag}}" class="form-control"
                                       placeholder="{{ __('VCUK') }}" required />
                            </div>
                        </div><!--form-group-->


                        <div class="form-group row">
                            <label for="type_id" class="col-md-4 col-form-label">@lang('Product Type')</label>

                            <div class="col-md-8">
                                <select class="form-control" name="type_id" id="type_id"
                                        onchange="getProductTypeFields(this.value)" required>
                                    @foreach($types as $type)
                                        <option value="{{$type->id}}"
                                                @if($type->id == $product->type_id)
                                                selected=""
                                            @endif
                                        >{{$type->name}}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div><!--form-group-->


                        @foreach($typeFields as $typeField)
                            <div class="form-group row type_fields_div type_fields_div_{{$typeField->type_id}}"
                                 style="display: none;">
                                <label for="type_field_{{$typeField->id}}"
                                       class="col-md-4 col-form-label">@lang($typeField->name)</label>

                                <div class="col-md-8">
                                    @php
                                        $fieldValue = $productTypeFields->filter(function ($field) use($typeField) {
                                            return $field->name == $typeField->name && $field->type_id == $typeField->type_id;
                                        });

                                        $fieldValue = $fieldValue->pluck('value')->first();
                                    @endphp
                                    <input type="hidden" name="type_fields_id[]" value="{{$typeField->type_id}}">
                                    <input type="hidden" name="type_fields_name[]" value="{{$typeField->name}}">
                                    <input type="text" name="type_fields_value[]"
                                           value="{{isset($fieldValue) ? $fieldValue : ''}}"
                                           id="type_field_{{$typeField->id}}" class="type_field_input form-control"
                                           placeholder="{{ __($typeField->name) }}" autocomplete="off" />
                                </div>
                            </div><!--form-group-->
                        @endforeach


                        <div class="form-group row">
                            <label for="embroidered_or_printed"
                                   class="col-md-4 col-form-label">@lang('Embroidered or Printed')</label>

                            <div class="col-md-8">
                                <select class="form-control" name="embroidered_or_printed" id="embroidered_or_printed">
                                    <option value="">Select Embroidered/Printed</option>
                                    @foreach($embroideredPrinted as $embroideredPrint)
                                        <option value="{{$embroideredPrint->name}}"
                                                @if($embroideredPrint->name == $product->embroidered_or_printed) selected @endif>{{$embroideredPrint->name}}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div><!--form-group-->


                        <div class="form-group row">
                            <label for="brand_id" class="col-md-4 col-form-label">@lang('Brand')</label>

                            <div class="col-md-8">
                                <input class="form-control" autocomplete="off" name="brand_id" value="{{ isset($product->brand->name) ? $product->brand->name : '' }}" list="brand_list" id="brand_id" placeholder="Brand" required>
                                <datalist id="brand_list">
                                    @foreach($brands as $brand)
                                        <option>{{$brand->name}}</option>
                                    @endforeach
                                </datalist>
                            </div>
                        </div><!--form-group-->


                        @if($productVariants)
                            @foreach($productVariants as $key => $values)

                                <div class="form-group row">
                                    <label for="variants_id{{$key}}" class="col-md-4 col-form-label">@lang($key)</label>

                                    <div class="col-md-8">
                                        @foreach($values as $value)
                                            <div id="variants_cloned">
                                                <div id="variants_for_clone{{$key}}" class="mb-1">
                                                    @foreach($variants as $subkey => $subvalues)
                                                        <input type="hidden" name="variant_name[]" value="{{$subkey}}">
                                                        <select name="variant_value[]"
                                                                class="variant_select2 form-control"
                                                                id="variants_id{{$subkey}}" required>
                                                            <option value="">Select {{$key}}</option>
                                                            @foreach($subvalues as $subvalue)
                                                                <option
                                                                    value="{{$subvalue}}"
                                                                    @if($key == $subkey && $value == $subvalue)
                                                                    selected
                                                                    @endif
                                                                >
                                                                    {{$subvalue}}
                                                                </option>
                                                            @endforeach
                                                        </select>
                                                    @endforeach
                                                </div>
                                            </div>
                                        @endforeach

                                        <a onclick="addAnotherVariant('{{$key}}')" style="cursor: pointer; color:blue;">+Add
                                            another {{$key}}</a>
                                    </div>
                                </div><!--form-group-->
                            @endforeach

                        @else
                            @foreach($variants as $key => $values)
                                <div class="form-group row">
                                    <label for="variants_id{{$key}}" class="col-md-4 col-form-label">@lang($key)</label>

                                    <div class="col-md-8">
                                        <div id="variants_cloned">
                                            <div id="variants_for_clone{{$key}}">
                                                <input type="hidden" name="variant_name[]" value="{{$key}}">
                                                <input class="form-control" name="variant_value[]"
                                                       placeholder="{{$key}}" id="variants_id{{$key}}"
                                                       list="variants_list"  style="margin-bottom: 7px;">
                                            </div>
                                            <datalist id="variants_list">
                                                @foreach($values as $value)
                                                    <option value="{{$value}}">
                                                @endforeach
                                            </datalist>
                                        </div>

                                        <a onclick="addAnotherVariant('{{$key}}')" style="cursor: pointer; color:blue;">+Add
                                            another {{$key}}</a>
                                    </div>
                                </div><!--form-group-->
                            @endforeach
                        @endif

                        <div class="form-group row">
                            <label for="size_on_label" class="col-md-4 col-form-label">@lang('Size on Label')</label>

                            <div class="col-md-8">
                                <select class="form-control" name="size_on_label" id="size_on_label" required>
                                    <option value="">Select Size</option>
                                    @foreach($sizeOnLabels as $sizeOnLebel)
                                        <option value="{{$sizeOnLebel->name}}"
                                                @if($sizeOnLebel->name == $product->size_on_label) selected @endif>{{$sizeOnLebel->name}}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div><!--form-group-->


                        <div class="form-group row true_size_field @if($product->reworks == null) true_size_field_hide @endif">
                            <label for="true_size" class="col-md-4 col-form-label">@lang('True Size')</label>

                            <div class="col-md-8">
                                <select class="form-control" name="true_size" id="true_size" required>
                                    <option value="">Select True Size</option>
                                    @foreach($truesizes as $truesize)
                                        <option value="{{$truesize->name}}"
                                        @if($truesize->name == $product->truesizes) selected @endif>{{$truesize->name}}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div><!--form-group-->

                        <div class="form-group row">
                            <label for="recommended_size_id" class="col-md-4 col-form-label">@lang('Recommended Size')</label>

                            <div class="col-md-8">
                                <input class="form-control" autocomplete="off" name="recommended_size_id" value="{{ isset($product->recommended_size->name) ? $product->recommended_size->name : '' }}" list="recommended_size_list" id="recommended_size_id" placeholder="Recommended Size" required>
                                <datalist id="recommended_size_list">
                                    @foreach($recommendedSizes as $recommended_size)
                                        <option>{{$recommended_size->name}}</option>
                                    @endforeach
                                </datalist>
                            </div>
                        </div><!--form-group-->

                        <div class="form-group row">
                            <label for="material_id" class="col-md-4 col-form-label">@lang('Material')</label>

                            <div class="col-md-8">
                                <input class="form-control" autocomplete="off" name="material_id" value="{{ isset($product->material->name) ? $product->material->name : '' }}" list="material_list" id="material_id" placeholder="Material" required>
                                <datalist id="material_list">
                                    @foreach($materials as $material)
                                        <option>{{$material->name}}</option>
                                    @endforeach
                                </datalist>
                            </div>
                        </div>

                        <div class="form-group row">
                            <label for="damage_preset" class="col-md-4 col-form-label">@lang('Damage Preset')</label>

                            <div class="col-md-8">
                            <?php
                                $other_true = "";
                                foreach($damagePresets as $damagePreset){
                                    if($damagePreset != $product->damage_preset){
                                        $other_true = $product->damage_preset;
                                    }
                                }
                            ?>
                                <select class="form-control" name="damage_preset" id="damage_preset" required>


                                    @if($other_true)
                                    <option value="{{$product->damage_preset}}" selected>{{$product->damage_preset}}</option>
                                    @endif
                                    @foreach($damagePresets as $damagePreset)
                                        <option value="{{$damagePreset->name}}"
                                                @if($damagePreset->name == $product->damage_preset) selected @endif
                                        >{{$damagePreset->name}}</option>
                                    @endforeach
                                </select>
                                <input style="display:none;" type="text" class="form-control" name="" id="damage_preset_text">
                            </div>
                        </div><!--form-group-->


                        <div class="form-group row">
                            <label for="gender" class="col-md-4 col-form-label">@lang('Gender')</label>

                            <div class="col-md-8">
                                <select class="form-control" name="gender" id="gender" required>
                                    @foreach($genders as $gender)
                                        <option value="{{$gender->gender}}"
                                                @if($gender->gender == $product->gender) selected @endif>{{$gender->gender}}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div><!--form-group-->

                        <div class="form-group row rework_field @if($product->reworks == null) rework_field_hide @endif">
                            <label for="unique_tag" class="col-md-4 col-form-label">@lang('Rework')</label>
                            @php
                            $rework_name = '';
                            if($product->reworks != null){
                                $rework_name = 'rework';
                            }

                            @endphp
                            <div class="col-md-8">
                            <select class="form-control" name="{{$rework_name}}" id="rework_id" required>
                                    @foreach($reworks as $rework)
                                        <option value="{{$rework->name}}" @if($rework->name == $product->reworks ) selected @endif>{{$rework->name}}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div><!--form-group-->

                    </div>
                </div>
            </x-slot>

            <x-slot name="footer">
                {{--                <button class="btn btn-sm btn-default float-right" id="downloadAllButton" type="submit">@lang('Outstanding')</button>--}}
                <button class="btn btn-sm btn-primary float-right" type="submit">@lang('Approve')</button>
            </x-slot>
        </x-backend.card>
    </x-forms.post>
@endsection

@push('after-scripts')
    <script src="{{ asset('js/jquery.flexdatalist.min.js') }}"></script>
    <script>
        $('#updateBarcodeData').click(function () {
            var actionUrl = "{{ route('admin.product.setBarcodeData') }}";
            $.ajax({
                type: "PUT",
                url: actionUrl,
                dataType:'json',
                data:{
                    product_id : $('#product_id').val(),
                    _token : "<?php echo csrf_token() ?>"
                },
                success: function(data)
                {
                    $('#ajax_call_alerts').html('<div class="alert alert-success header-message" role="alert"> Barcode Data successfully updated. <button type="button" class="close" data-dismiss="alert" aria-label="Close"> <span aria-hidden="true">&times;</span></button></div>');
                },
                error: function(xhr, status, error) {
                    $('#ajax_call_alerts').html('<div class="alert alert-danger header-message" role="alert"> <b>Error Type: </b>'+ error +', <br> <b>Error:</b> '+ xhr.responseJSON.message +' <button type="button" class="close" data-dismiss="alert" aria-label="Close"> <span aria-hidden="true">&times;</span></button></div>');
                }
            });
        });


        $("#arrivalCheckForm input").on('keyup keypress',function(e) {
            var keyCode = e.keyCode || e.which;
            if (keyCode === 13) {
                return false;
            }
        });

        function addAnotherVariant(id) {
            $('#variants_for_clone' + id).clone().appendTo('#variants_cloned');
        }

        function getProductTypeFields(id) {

            $(".type_fields_div .type_field_input").val('');
            $(".type_fields_div").hide();
            $(".type_fields_div input").prop('required', false);

            $(".type_fields_div_"+id).show();
            $(".type_fields_div_"+id+" input").prop('required', true);
        }

        $(".type_fields_div_{{$product->type_id}}").show();

        $('#downloadAllButton').click(function () {
            $('img.download_file').each(function () {
                $this = $(this);                      //save the $(this) object
                $('body').append($('<a>')       //append a new '<a>' element to the DOM
                    .css('display', 'none')             //hide the new '<a>' element
                    .attr('href', $this.attr('src'))  //make the image path the link href
                    .attr('download', $this.attr('src').replace('{{Storage::url('products/')}}', ''))           //keep the file name
                    .append($this.clone()))       //copy the image into the new '<a>' element
                    .find('img:last()')         //obtain a reference to the copied image
                    .trigger('click');      //fire the click event

                $('a:last()').remove();
            });
            return false;
        });
        // $("#type_id").trigger('change');

        $("#arrivalCheckForm").validate({
            submitHandler: function (form) {
                form.submit();
            }
        });

        $('#arrivalCheckForm input').on('keyup blur', function () { // fires on every keyup & blur
            $('#arrivalCheckForm button.btn').prop('disabled', false);        // enables button
        });

        function DetailKeySystem(id) {
            var detail_name = $('#detail_field_name_' + id);
            var detail_value = $('#detail_field_' + id);
            detail_value.val('');
            $.each({!! $details !!}, function (index, value) {
                if (detail_name.val() === value.name) {
                    detail_value.val(value.value);
                }
            });
        }

        // $("#brand_id").flexdatalist({
        //     focusFirstResult: true,
        //     noResultsText: false,
        //     searchContain: true,
        //     searchDelay: 100
        // });

        $("#damage_preset").on('change', function(){
                if($(this).val() == "Other"){
                    $(this).attr('name', '');
                    $('#damage_preset_text').attr('name', 'damage_preset');
                    $('#damage_preset_text').show();
                }else{
                    $(this).attr('name', 'damage_preset');
                    $('#damage_preset_text').attr('name', '');
                    $('#damage_preset_text').hide();
                }
            });

            $("#damage_preset").on('change', function(){
                if($(this).val() == "Other"){
                    $(this).attr('name', '');
                    $('#damage_preset_text').attr('name', 'damage_preset');
                    $('#damage_preset_text').show();
                }else{
                    $(this).attr('name', 'damage_preset');
                    $('#damage_preset_text').attr('name', '');
                    $('#damage_preset_text').hide();
                }
            });


            $(document).on("change", "#rework_check", function () {
                    if($(this).is(':checked')){
                        $(".rework_field").removeClass('rework_field_hide');
                        $(".true_size_field").removeClass('true_size_field_hide');
                        $("#rework_id").attr('name', 'rework');
                    }else{
                        $(".rework_field").addClass('rework_field_hide');
                        $(".true_size_field").addClass('true_size_field_hide');
                        $("#rework_id").attr('name', '');
                    }
            });

    </script>
@endpush


@push('after-styles')
    <link href="{{ asset('css/jquery.flexdatalist.min.css') }}" rel="stylesheet">
    <style>
        .form-check .form-check-label{
            height: inherit;
            width: 100%;
            margin: -7px -24px;
            position: absolute;
            padding: 8px 22px;
        }
        .bggray-box{
            border-radius: 0.5em;
            background-color: #f1f0ef !important;
            padding: 15px;
            margin-bottom: 12px;
        }
        .form-check label.error{
            display: block !important;
            position: absolute;
            margin: 28px -3px;
            color: red;
        }
    </style>
@endpush
