@inject('model', '\App\Domains\Product\Models\Product')

@extends('backend.layouts.app')

@section('title', __('Create Product'))

@section('content')

    <span id="ajax_call_alerts"></span>

    <x-forms.post :action="route('admin.product.store')" id="productCreateForm" enctype="multipart/form-data" onsubmit="return false;">
        <x-backend.card>
            <x-slot name="header">
                @lang('Create Product')
            </x-slot>

            <x-slot name="headerActions">
                <x-utils.link class="card-header-action" :href="route('admin.product.all')" :text="__('Cancel')"/>
            </x-slot>

            <x-slot name="body">
                <div class="row">
                    <div class="col-lg-5">

                        <input type="file"
                               name="photos[]"
                               id="file-uploader"
                               multiple
                               data-allow-reorder="true"
                               data-max-files="4"/>

                        <span style="color:red;" id="photos-error"></span>

                        <div class="rework_section">
                            <div class="form-group row">
                                <label for="brand_id">@lang('Rework')</label>
                                <input type="checkbox" id="rework_check" name="rework_check">
                            </div>
                        </div>

                    </div>
                    <input type="hidden" name="user_id" value="{{auth()->id()}}"/>
                    <div class="col-lg-7">
                        <div class="form-group row">
                            <label for="brand_id" class="col-md-4 col-form-label">@lang('Brand')</label>

                            <div class="col-md-8">
                                <input class="form-control" autocomplete="off" name="brand_id" value="{{ isset($product->brand->name) ? $product->brand->name : '' }}" list="brand_list" id="brand_id" placeholder="Brand" required>
                                <datalist id="brand_list">
                                    @foreach($brands as $brand)
                                        <option>{{$brand->name}}</option>
                                    @endforeach
                                </datalist>
                            </div>
                        </div><!--form-group-->

                        <div class="form-group row">
                            <label for="type_id" class="col-md-4 col-form-label">@lang('Product Type')</label>

                            <div class="col-md-8">
                                <select class="form-control" name="type_id" id="type_id" onchange="getProductTypeFields(this.value)" required>
                                    @foreach($types as $type)
                                        <option value="{{$type->id}}" @if($product && $product->type_id == $type->id) selected @endif>{{$type->name}}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div><!--form-group-->


                        <div class="form-group row">
                            <label for="embroidered_or_printed"
                                   class="col-md-4 col-form-label">@lang('Embroidered or Printed')</label>

                            <div class="col-md-8">
                                <select class="form-control" name="embroidered_or_printed" id="embroidered_or_printed">
                                    <option value="">Select Embroidered/Printed</option>
                                    @foreach($embroideredPrinted as $embroideredPrint)
                                        <option value="{{$embroideredPrint->name}}">{{$embroideredPrint->name}}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div><!--form-group-->


                        @foreach($variants as $key => $values)
                            <div class="form-group row">
                                <label for="variants_id{{$key}}" class="col-md-4 col-form-label">@lang($key)</label>

                                <div class="col-md-8">
                                    <div class="original_variant">
                                        <div id="variants_for_clone{{$key}}" class="mb-1">
                                            <input type="hidden" name="variant_name[]" value="{{$key}}">
                                            <select name="variant_value[]" class="variant_select2 form-control" id="variants_id{{$key}}" required>
                                                <option value="">Select {{$key}}</option>
                                                @foreach($values as $value)
                                                    <option value="{{$value}}">{{$value}}</option>
                                                @endforeach
                                            </select>
                                        </div>
                                    </div>
                                    <div id="variants_cloned">

                                    </div>

                                    <a onclick="addAnotherVariant('{{$key}}')" style="cursor: pointer; color:blue;">+Add another {{$key}}</a>
                                </div>
                            </div><!--form-group-->
                        @endforeach


                        @foreach($typeFields as $typeField)
                        <div class="form-group row type_fields_div type_fields_div_{{$typeField->type_id}}" style="display: none;">
                            <label for="type_field_{{$typeField->id}}" class="col-md-4 col-form-label">@lang($typeField->name)</label>

                            <div class="col-md-8">
                                <input type="hidden" name="type_fields_id[]" value="{{$typeField->type_id}}">
                                <input type="hidden" name="type_fields_name[]" value="{{$typeField->name}}">
                                <input type="text" name="type_fields_value[]" id="type_field_{{$typeField->id}}" class="type_field_input form-control"
                                       placeholder="{{ __($typeField->name) }}" autocomplete="off" />
                            </div>
                        </div><!--form-group-->
                        @endforeach


                        <div class="form-group row">
                            <label for="size_on_label" class="col-md-4 col-form-label">@lang('Size on Label')</label>

                            <div class="col-md-8">
                                <select class="form-control" name="size_on_label" id="size_on_label" required>
                                    <option value="">Select Size</option>
                                    @foreach($sizeOnLabels as $sizeOnLebel)
                                        <option value="{{$sizeOnLebel->name}}">{{$sizeOnLebel->name}}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div><!--form-group-->


                        <div class="form-group row true_size_field true_size_field_hide">
                            <label for="true_size" class="col-md-4 col-form-label">@lang('True Size')</label>

                            <div class="col-md-8">
                                <select class="form-control" name="true_size" id="true_size" required>
                                    <option value="">Select True Size</option>
                                    @foreach($truesizes as $truesize)
                                        <option value="{{$truesize->name}}">{{$truesize->name}}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div><!--form-group-->

                        <div class="form-group row">
                            <label for="recommended_size_id" class="col-md-4 col-form-label">@lang('Recommended Size')</label>

                            <div class="col-md-8">
                                <input class="form-control" autocomplete="off" name="recommended_size_id" list="recommended_size_list" id="recommended_size_id" placeholder="Recommended Size" required>
                                <datalist id="recommended_size_list">
                                    @foreach($recommendedSizes as $recommended_size)
                                        <option>{{$recommended_size->name}}</option>
                                    @endforeach
                                </datalist>
                            </div>
                        </div>

                        <div class="form-group row">
                            <label for="material_id" class="col-md-4 col-form-label">@lang('Material')</label>

                            <div class="col-md-8">
                                <input class="form-control" autocomplete="off" name="material_id" list="material_list" id="material_id" placeholder="Material" required>
                                <datalist id="material_list">
                                    @foreach($materials as $material)
                                        <option>{{$material->name}}</option>
                                    @endforeach
                                </datalist>
                            </div>
                        </div>

                        <div class="form-group row">
                            <label for="damage_preset" class="col-md-4 col-form-label">@lang('Damage Preset')</label>

                            <div class="col-md-8">
                                <select class="form-control" name="damage_preset" id="damage_preset" >
                                    @foreach($damagePresets as $damagePreset)
                                        <option value="{{$damagePreset->name}}" @if(\Str::contains($damagePreset->name, 'Vintage Quality')) selected @endif>{{$damagePreset->name}}</option>
                                    @endforeach
                                </select>
                                <input style="display:none;" type="text" class="form-control" name="" id="damage_preset_text">
                            </div>
                        </div><!--form-group-->




                        <div class="form-group row">
                            <label for="gender" class="col-md-4 col-form-label">@lang('Gender')</label>

                            <div class="col-md-8">
                                <select class="form-control" name="gender" id="gender" >
                                    @foreach($genders as $gender)
                                        <option value="{{$gender->gender}}" @if($product && $product->gender == $gender->gender) selected @endif>{{$gender->gender}}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div><!--form-group-->

                        <div class="form-group row">
                            <label for="unique_tag" class="col-md-4 col-form-label">@lang('Unique Tag')</label>

                            <div class="col-md-8">
                                <input type="text" name="unique_tag" value="{{ $unique_tag }}" id="unique_tag" class="form-control"
                                       placeholder="{{ __('Unique Tag') }}" required readonly/>
                            </div>
                        </div><!--form-group-->

                        <div class="form-group row rework_field rework_field_hide">
                            <label for="unique_tag" class="col-md-4 col-form-label">@lang('Rework')</label>

                            <div class="col-md-8">
                            <select class="form-control" name="" id="rework_id">
                                    @foreach($reworks as $rework)
                                        <option value="{{$rework->name}}" @if($rework->name == 'COOGI') selected @endif>{{$rework->name}}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div><!--form-group-->

                    </div>
                </div>
            </x-slot>

            <x-slot name="footer">
                <button class="btn btn-sm btn-primary float-right" type="submit">@lang('Complete')</button>
            </x-slot>
        </x-backend.card>
    </x-forms.post>

@endsection

@push('after-scripts')
<script>
    function addAnotherVariant(id){
       $('#variants_for_clone'+id).first().clone(true).appendTo('#variants_cloned');
    }

    function getProductTypeFields(id)
    {
        $(".type_fields_div .type_field_input").val('');
        $(".type_fields_div").hide();
        $(".type_fields_div input").prop('required', false);

        $(".type_fields_div_"+id).show();
        $(".type_fields_div_"+id+" input").prop('required', true);
    }

</script>
@endpush


@push('after-styles')
    <link href="{{ asset('css/jquery.flexdatalist.min.css') }}" rel="stylesheet">
    <style>
        .filepond--item[data-drag-state]{
            width: 48% !important;
            display: inline-block !important;
        }
        .filepond--root .filepond--credits[style]{
            display: none !important;
        }
    </style>
@endpush

@push('after-scripts')
    <script src="{{ asset('js/jquery.flexdatalist.min.js') }}"></script>
    <script>
        $("#productCreateForm input").on('keyup keypress',function(e) {
            var keyCode = e.keyCode || e.which;
            if (keyCode === 13) {
                enter = keyCode;
                return false;
            }
        });

        $("#productCreateForm").validate({
            submitHandler: function(form) {

                if($('input[name*="photos"]').length === 4)
                {
                    // form.submit();
                    var form = $(form);
                    var actionUrl = form.attr('action');
                    $.ajax({
                        type: "POST",
                        url: actionUrl,
                        data: form.serialize(), // serializes the form's elements.
                        beforeSend : function(){
                            $('#size_on_label').val('');
                            $('#damage_preset').val( $('#damage_preset').find("option[selected]").val() );
                            $('.original_variant select').val('');
                            $('#variants_cloned').html('');
                            $('.type_field_input').val('');
                            window.scrollTo(0, 0);
                            removeFilesToPond();
                            $('#ajax_call_alerts').html('<div class="alert alert-success header-message" role="alert"> Submitting... <button type="button" class="close" data-dismiss="alert" aria-label="Close"> <span aria-hidden="true">&times;</span></button></div>');

                            window.onbeforeunload = function() {
                                return "are you sure you want to leave?";
                            }
                        },
                        success: function(data)
                        {
                            $('#ajax_call_alerts').html('<div class="alert alert-success header-message" role="alert"> The product was successfully created. <button type="button" class="close" data-dismiss="alert" aria-label="Close"> <span aria-hidden="true">&times;</span></button></div>');
                            window.onbeforeunload = null;
                            $('#unique_tag').val(data.unique_tag);
                        },
                        error: function(xhr, status, error) {
                            $('#ajax_call_alerts').html('<div class="alert alert-danger header-message" role="alert"> <b>Error Type: </b>'+ error +', <br> <b>Error:</b> '+ xhr.responseJSON.message +' <button type="button" class="close" data-dismiss="alert" aria-label="Close"> <span aria-hidden="true">&times;</span></button></div>');
                        }
                    });

                }else{
                    $('#photos-error').html('Photos must be 4 minimum.');
                    window.scrollTo(0, 0);
                    $('#productCreateForm button.btn').prop('disabled', false);        // enables button
                    return false;
                }
            }
        });

        $('#productCreateForm input, #productCreateForm select').on('keyup blur', function () { // fires on every keyup & blur
            $('#productCreateForm button.btn').prop('disabled', false);        // enables button
        });

        $("#type_id").trigger('change');

        // $("#brand_id").flexdatalist({
        //     noResultsText: false,
        //     searchContain: true,
        //     searchDelay: 100,
        //     minLength: 0
        // });
            $("#damage_preset").on('change', function(){
                if($(this).val() == "Other"){
                    $(this).attr('name', '');
                    $('#damage_preset_text').attr('name', 'damage_preset');
                    $('#damage_preset_text').show();
                }else{
                    $(this).attr('name', 'damage_preset');
                    $('#damage_preset_text').attr('name', '');
                    $('#damage_preset_text').hide();
                }
            });


            $(document).on("change", "#rework_check", function () {
                    if($(this).is(':checked')){
                        $(".rework_field").removeClass('rework_field_hide');
                        $(".true_size_field").removeClass('true_size_field_hide');
                        $("#rework_id").attr('name', 'rework');
                    }else{
                        $(".rework_field").addClass('rework_field_hide');
                        $(".true_size_field").addClass('true_size_field_hide');
                        $("#rework_id").attr('name', '');
                    }
            });

        // this is the id of the form
    </script>
@endpush
