@inject('model', '\App\Domains\Product\Models\Product')

@extends('backend.layouts.app')

@section('title', __('Edit Product'))

@section('content')
    <x-forms.post :action="route('admin.product.update', $product->id)" id="editCreateForm" enctype="multipart/form-data">
        <x-backend.card>
            <x-slot name="header">
                @lang('Edit Product')
            </x-slot>

            <x-slot name="headerActions">
                <x-utils.link class="card-header-action" :href="route('admin.product.all')" :text="__('Cancel')"/>
            </x-slot>

            <x-slot name="body">
                <div class="row">
                    <div class="col-lg-5">

                        <input type="file"
                               name="photos[]"
                               id="file-uploader"
                               multiple
                               data-allow-reorder="true"/>

                        <span style="color:red;" id="photos-error"></span>

                    </div>
                    <div class="col-lg-7">

                        <div class="form-group row">
                            <label for="brand_id" class="col-md-4 col-form-label">@lang('Brand')</label>

                            <div class="col-md-8">
                                <input class="form-control" name="brand_id" autocomplete="off" value="{{ isset($product->brand->name) ? $product->brand->name : '' }}" list="brand_list" id="brand_id" placeholder="Brand" required>
                                <datalist id="brand_list">
                                    @foreach($brands as $brand)
                                        <option>{{$brand->name}}</option>
                                    @endforeach
                                </datalist>
                            </div>
                        </div><!--form-group-->

                        <div class="form-group row">
                            <label for="type_id" class="col-md-4 col-form-label">@lang('Product Type')</label>

                            <div class="col-md-8">
                                <select class="form-control" name="type_id" id="type_id" onchange="getProductTypeFields(this.value)" required>
                                    @foreach($types as $type)
                                        <option value="{{$type->id}}"
                                                @if($type->id == $product->type_id)
                                                selected=""
                                            @endif
                                        >{{$type->name}}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div><!--form-group-->


                        <div class="form-group row">
                            <label for="embroidered_or_printed"
                                   class="col-md-4 col-form-label">@lang('Embroidered or Printed')</label>

                            <div class="col-md-8">
                                <select class="form-control" name="embroidered_or_printed" id="embroidered_or_printed">
                                    <option value="">Select Embroidered/Printed</option>
                                    @foreach($embroideredPrinted as $embroideredPrint)
                                        <option value="{{$embroideredPrint->name}}" @if($embroideredPrint->name == $product->embroidered_or_printed) selected @endif>{{$embroideredPrint->name}}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div><!--form-group-->


                        @if($productVariants)
                            @foreach($productVariants as $key => $values)

                                <div class="form-group row">
                                    <label for="variants_id{{$key}}" class="col-md-4 col-form-label">@lang($key)</label>

                                    <div class="col-md-8">
                                        @foreach($values as $value)
                                            <div id="variants_cloned">
                                                <div id="variants_for_clone{{$key}}" class="mb-1">
                                                    @foreach($variants as $subkey => $subvalues)
                                                        <input type="hidden" name="variant_name[]" value="{{$subkey}}">
                                                        <select name="variant_value[]" class="variant_select2 form-control" id="variants_id{{$subkey}}" required>
                                                            <option value="">Select {{$key}}</option>
                                                            @foreach($subvalues as $subvalue)
                                                                <option
                                                                    value="{{$subvalue}}"
                                                                    @if($key == $subkey && $value == $subvalue)
                                                                    selected
                                                                    @endif
                                                                >
                                                                    {{$subvalue}}
                                                                </option>
                                                            @endforeach
                                                        </select>
                                                    @endforeach
                                                </div>
                                            </div>
                                        @endforeach

                                        <a onclick="addAnotherVariant('{{$key}}')" style="cursor: pointer; color:blue;">+Add another {{$key}}</a>
                                    </div>
                                </div><!--form-group-->
                            @endforeach

                        @else
                            @foreach($variants as $key => $values)
                                <div class="form-group row">
                                    <label for="variants_id{{$key}}" class="col-md-4 col-form-label">@lang($key)</label>

                                    <div class="col-md-8">
                                        <div id="variants_cloned">
                                            <div id="variants_for_clone{{$key}}">
                                                <input type="hidden" name="variant_name[]" value="{{$key}}">
                                                <input class="form-control" name="variant_value[]" placeholder="{{$key}}" id="variants_id{{$key}}" list="variants_list" required style="margin-bottom: 7px;">
                                            </div>
                                            <datalist id="variants_list">
                                                @foreach($values as $value)
                                                    <option value="{{$value}}">
                                                @endforeach
                                            </datalist>
                                        </div>

                                        <a onclick="addAnotherVariant('{{$key}}')" style="cursor: pointer; color:blue;">+Add another {{$key}}</a>
                                    </div>
                                </div><!--form-group-->
                            @endforeach
                        @endif

                        <div class="form-group row">
                            <label for="size_on_label" class="col-md-4 col-form-label">@lang('Size on Label')</label>

                            <div class="col-md-8">
                                <select class="form-control" name="size_on_label" id="size_on_label" required>
                                    <option value="">Select Size</option>
                                    @foreach($sizeOnLabels as $sizeOnLebel)
                                        <option value="{{$sizeOnLebel->name}}" @if($sizeOnLebel->name == $product->size_on_label) selected @endif>{{$sizeOnLebel->name}}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div><!--form-group-->

                        <div class="form-group row">
                            <label for="recommended_size_id" class="col-md-4 col-form-label">@lang('Recommended Size')</label>

                            <div class="col-md-8">
                                <input class="form-control" autocomplete="off" name="recommended_size_id" value="{{ isset($product->recommended_size->name) ? $product->recommended_size->name : '' }}" list="recommended_size_list" id="recommended_size_id" placeholder="Recommended Size" required>
                                <datalist id="recommended_size_list">
                                    @foreach($recommendedSizes as $recommended_size)
                                        <option>{{$recommended_size->name}}</option>
                                    @endforeach
                                </datalist>
                            </div>
                        </div>

                        <div class="form-group row">
                            <label for="material_id" class="col-md-4 col-form-label">@lang('Material')</label>

                            <div class="col-md-8">
                                <input class="form-control" autocomplete="off" name="material_id" value="{{ isset($product->material->name) ? $product->material->name : '' }}" list="material_list" id="material_id" placeholder="Material" required>
                                <datalist id="material_list">
                                    @foreach($materials as $material)
                                        <option>{{$material->name}}</option>
                                    @endforeach
                                </datalist>
                            </div>
                        </div>

                        <div class="form-group row">
                            <label for="damage_preset" class="col-md-4 col-form-label">@lang('Damage Preset')</label>

                            <div class="col-md-8">
                                <select class="form-control" name="damage_preset" id="damage_preset" required>
                                    @foreach($damagePresets as $damagePreset)
                                        <option value="{{$damagePreset->name}}" @if($damagePreset->name == $product->damage_preset) selected @endif >{{$damagePreset->name}}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div><!--form-group-->


                        @foreach($typeFields as $typeField)
                            <div class="form-group row type_fields_div type_fields_div_{{$typeField->type_id}}"
                                 style="display: none;">
                                <label for="type_field_{{$typeField->id}}"
                                       class="col-md-4 col-form-label">@lang($typeField->name)</label>

                                <div class="col-md-8">
                                    @php
                                        $fieldValue = $productTypeFields->filter(function ($field) use($typeField) {
                                            return $field->name == $typeField->name && $field->type_id == $typeField->type_id;
                                        });

                                        $fieldValue = $fieldValue->pluck('value')->first();
                                    @endphp
                                    <input type="hidden" name="type_fields_id[]" value="{{$typeField->type_id}}">
                                    <input type="hidden" name="type_fields_name[]" value="{{$typeField->name}}">
                                    <input type="text" name="type_fields_value[]"
                                           value="{{isset($fieldValue) ? $fieldValue : ''}}"
                                           id="type_field_{{$typeField->id}}" class="type_field_input form-control"
                                           placeholder="{{ __($typeField->name) }}" autocomplete="off" />
                                </div>
                            </div><!--form-group-->
                        @endforeach



                        <div class="form-group row">
                            <label for="gender" class="col-md-4 col-form-label">@lang('Gender')</label>

                            <div class="col-md-8">
                                <select class="form-control" name="gender" id="gender" required>
                                    @foreach($genders as $gender)
                                        <option value="{{$gender->gender}}" @if($gender->gender == $product->gender) selected @endif>{{$gender->gender}}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div><!--form-group-->

                        <div class="form-group row">
                            <label for="unique_tag" class="col-md-4 col-form-label">@lang('Unique Tag')</label>

                            <div class="col-md-8">
                                <input type="text" name="unique_tag" value="{{$product->unique_tag}}" id="unique_tag" class="form-control"
                                       placeholder="{{ __('Unique Tag') }}" readonly/>
                            </div>
                        </div><!--form-group-->

                    </div>
                </div>
            </x-slot>

            <x-slot name="footer">
                <button class="btn btn-sm btn-primary float-right" type="submit">@lang('Complete')</button>
            </x-slot>
        </x-backend.card>
    </x-forms.post>
@endsection

@push('after-scripts')
<script>
    function addAnotherVariant(id){
        $('#variants_for_clone'+id).first().clone().appendTo('#variants_cloned');
    }

    function getProductTypeFields(id) {

        $(".type_fields_div .type_field_input").val('');
        $(".type_fields_div").hide();
        $(".type_fields_div input").prop('required', false);

        $(".type_fields_div_"+id).show();
        $(".type_fields_div_"+id+" input").prop('required', true);
    }

    $(".type_fields_div_{{$product->type_id}}").show();

</script>
@endpush


@push('after-styles')
    <link href="{{ asset('css/jquery.flexdatalist.min.css') }}" rel="stylesheet">
    <style>
        .filepond--item[data-drag-state]{
            width: 48% !important;
            display: inline-block !important;
        }
        .filepond--root .filepond--credits[style]{
            display: none !important;
        }
    </style>
@endpush

@push('after-scripts')
    <script src="{{ asset('js/jquery.flexdatalist.min.js') }}"></script>
    <script>

        $("#editCreateForm input").on('keyup keypress',function(e) {
            var keyCode = e.keyCode || e.which;
            if (keyCode === 13) {
                return false;
            }
        });

        $("#editCreateForm").validate({
            submitHandler: function(form) {
                if($('input[name*="photos"]').length >= 4)
                {
                    form.submit();
                }else{
                    $('#photos-error').html('Photos must be 4 minimum.');
                    window.scrollTo(0, 0);
                    return false;
                }
            }
        });

        $('#editCreateForm input').on('keyup blur', function () { // fires on every keyup & blur
            if ($('#editCreateForm').valid()) {                   // checks form for validity
                $('#editCreateForm button.btn').prop('disabled', false);        // enables button
            } else {
                $('#editCreateForm button.btn').prop('disabled', 'disabled');   // disables button
            }
        });
        // $("#type_id").trigger('change');

        @php $photo_url = []; @endphp
        @foreach($product->photos as $photo)
            @php $photo_url[] = Storage::url($photo->url); @endphp
        @endforeach

        addFilesToPond({!! json_encode($photo_url) !!});

        // $("#brand_id").flexdatalist({
        //     focusFirstResult: true,
        //     noResultsText: false,
        //     searchContain: true,
        //     searchDelay: 100
        // });
    </script>
@endpush
