@inject('model', '\App\Domains\Product\Models\Product')

@extends('backend.layouts.app')

@section('title', __('Pre Check Product ('.$product->unique_tag.')'))

@section('content')
    <x-forms.post :action="route('admin.product.pre_check.product.store', $product->id)" id="preCheckForm" enctype="multipart/form-data">
        @method('PUT')
        <x-backend.card>
            <x-slot name="header">
                @lang('Pre Check Product ('.$product->unique_tag.')')
            </x-slot>

            <x-slot name="headerActions">
                <x-utils.link class="card-header-action" :href="route('admin.product.pre_check')" :text="__('Cancel')"/>
            </x-slot>

            <x-slot name="body">
                <div class="row">
                    <div class="col-lg-5">
                        <img class="w-100" src="{{$product->photos->first() ? Storage::url($product->photos->first()->url) : ''}}">
                    </div>
                    <div class="col-lg-7">
                        @for($i = 1; $i <= 3; $i++)
                            @php
                                    $detailValue = isset($productDetails[$i-1]) ? $productDetails[$i-1] : null;
                            @endphp
                            <div class="form-group row">
                                <label for="detail_field_{{$i}}" class="col-md-4 col-form-label">@lang('Detail '.$i)</label>
                                <div class="col-md-4">
                                    <input type="text" name="detail_name[]" value="{{isset($detailValue->name) ? $detailValue->name : ''}}" id="detail_field_name_{{$i}}" onkeyup="DetailKeySystem('{{$i}}')" class="form-control">
                                </div>
                                <div class="col-md-4">
                                    <input type="text" name="detail_value[]" value="{{isset($detailValue->value) ? $detailValue->value : ''}}" id="detail_field_{{$i}}" placeholder="{{'Detail '.$i}}" class="form-control detailKeySystem">
                                </div>
                            </div><!--form-group-->
                        @endfor


                        <div class="form-group row">
                            @php
                               $detailLastValue = isset($productDetails[$i-1]) ? $productDetails[$i-1] : null;
                            @endphp
                            <label for="type_field_detail4" class="col-md-4 col-form-label">@lang('Detail '.$i)</label>
                            <div class="col-md-8">
                                <input type="hidden" name="detail_name[]" value="{{isset($detailLastValue->name) ? $detailLastValue->name : ''}}" class="form-control">
                                <input type="text" name="detail_value[]" value="{{isset($detailLastValue->value) ? $detailLastValue->value : ''}}" id="type_field_detail4" class="form-control"
                                       placeholder="{{ __('Detail '.$i) }}" />
                            </div>
                        </div><!--form-group-->

                        <div class="form-group row">
                            <label for="price" class="col-md-4 col-form-label">@lang('Price')</label>

                            <div class="col-md-8">
                                <input type="text" name="price" id="price" value="{{($product->price != 0 || !empty($product->price)) ? $product->price : ''}}" class="form-control"
                                       placeholder="{{ __('Price') }}" required/>
                            </div>
                        </div><!--form-group-->

                        <div class="form-group row">
                            <label for="type_id" class="col-md-4 col-form-label">@lang('Product Type')</label>

                            <div class="col-md-8">
                                <select class="form-control" name="type_id" id="type_id" onchange="getProductTypeFields(this.value)" required>
                                    @foreach($types as $type)
                                        <option value="{{$type->id}}"
                                            @if($type->id == $product->type_id)
                                                selected=""
                                            @endif
                                        >{{$type->name}}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div><!--form-group-->


                        @foreach($typeFields as $typeField)
                        <div class="form-group row type_fields_div type_fields_div_{{$typeField->type_id}}" style="display: none;">
                            <label for="type_field_{{$typeField->id}}" class="col-md-4 col-form-label">@lang($typeField->name)</label>

                            <div class="col-md-8">
                                @php
                                    $fieldValue = $productTypeFields->filter(function ($field) use($typeField) {
                                        return $field->name == $typeField->name;
                                    });

                                    $fieldValue = $fieldValue->pluck('value')->first();
                                @endphp
                                <input type="hidden" name="type_fields_name[]" value="{{$typeField->name}}">
                                <input type="text" name="type_fields_value[]" value="{{isset($fieldValue) ? $fieldValue : ''}}" id="type_field_{{$typeField->id}}" class="form-control"
                                       placeholder="{{ __($typeField->name) }}" />
                            </div>
                        </div><!--form-group-->
                        @endforeach


                        <div class="form-group row">
                            <label for="brand_id" class="col-md-4 col-form-label">@lang('Brand')</label>

                            <div class="col-md-8">
                                <select class="form-control" name="brand_id" id="brand_id" required>
                                    @foreach($brands as $brand)
                                        <option value="{{$brand->id}}"
                                            @if($brand->id == $product->brand_id)
                                                selected=""
                                            @endif
                                        >{{$brand->name}}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div><!--form-group-->
                        @if($productVariants)
                            @foreach($productVariants as $key => $values)
                            <div class="form-group row">
                                <label for="variants_id{{$key}}" class="col-md-4 col-form-label">@lang($key)</label>

                                <div class="col-md-8">
                                    @foreach($values as $value)
                                    <div id="variants_cloned">
                                        <div id="variants_for_clone{{$key}}">
                                            <input type="hidden" name="variant_name[]" value="{{$key}}">
                                            <input class="form-control" value="{{$value}}" name="variant_value[]" placeholder="{{$key}}" id="variants_id{{$key}}" list="variants_list" required style="margin-bottom: 7px;">
                                        </div>
                                    </div>
                                    @endforeach

                                    <a onclick="addAnotherVariant('{{$key}}')" style="cursor: pointer; color:blue;">+Add another {{$key}}</a>
                                </div>
                            </div><!--form-group-->
                            @endforeach

                            @foreach($variants as $key => $values)
                                <datalist id="variants_list">
                                    @foreach($values as $value)
                                        <option value="{{$value}}">
                                    @endforeach
                                </datalist>
                            @endforeach

                        @else
                            @foreach($variants as $key => $values)
                                <div class="form-group row">
                                    <label for="variants_id{{$key}}" class="col-md-4 col-form-label">@lang($key)</label>

                                    <div class="col-md-8">
                                        <div id="variants_cloned">
                                            <div id="variants_for_clone{{$key}}">
                                                <input type="hidden" name="variant_name[]" value="{{$key}}">
                                                <input class="form-control" name="variant_value[]" placeholder="{{$key}}" id="variants_id{{$key}}" list="variants_list" required style="margin-bottom: 7px;">
                                            </div>
                                            <datalist id="variants_list">
                                                @foreach($values as $value)
                                                    <option value="{{$value}}">
                                                @endforeach
                                            </datalist>
                                        </div>

                                        <a onclick="addAnotherVariant('{{$key}}')" style="cursor: pointer; color:blue;">+Add another {{$key}}</a>
                                    </div>
                                </div><!--form-group-->
                            @endforeach
                        @endif


                        <div class="form-group row">
                            <label class="col-md-4 col-form-label"></label>

                            <div class="col-md-8">
                                <div class="form-check">
                                    <input class="form-check-input" @if($product->gg == 1) checked @endif name="gg" type="checkbox" value="1" id="flexCheckDefault">
                                    <label class="form-check-label" for="flexCheckDefault">
                                        <b>GG</b>
                                    </label>
                                </div>
                            </div>
                        </div><!--form-group-->

                    </div>
                </div>
            </x-slot>

            <x-slot name="footer">
                <button class="btn btn-sm btn-primary float-right" type="submit">@lang('Complete')</button>
            </x-slot>
        </x-backend.card>
    </x-forms.post>
@endsection

@push('after-scripts')
<script>
    function addAnotherVariant(id){
        $('#variants_for_clone'+id).clone().appendTo('#variants_cloned');
    }

    function getProductTypeFields(id)
    {
        $(".type_fields_div").hide();
        $(".type_fields_div_"+id).show();
    }
    $(".type_fields_div_{{$product->type_id}}").show();
    $("#type_id").trigger('change');

    $("#preCheckForm").validate({
        submitHandler: function(form) {
            form.submit();
        }
    });

    $('#preCheckForm input').on('keyup blur', function () { // fires on every keyup & blur
        if ($('#preCheckForm').valid()) {                   // checks form for validity
            $('#preCheckForm button.btn').prop('disabled', false);        // enables button
        } else {
            $('#preCheckForm button.btn').prop('disabled', 'disabled');   // disables button
        }
    });




    function DetailKeySystem(id)
    {
        var detail_name = $('#detail_field_name_'+id);
        var detail_value = $('#detail_field_'+id);
        $.each({!! $details !!}, function( index, value ) {
            if(detail_name.val() === value.name)
            {
                detail_value.val(value.value);
            }
        });
    }

    $("#brand_id").select2({
        tags: true
    });
</script>
@endpush
