@inject('model', '\App\Domains\Product\Models\Product')

@extends('backend.layouts.app')

@section('title', __('Upload Product'))

@section('content')

    <x-forms.post :action="route('admin.product.upload.product.store', $product->id)" id="uploadForm" enctype="multipart/form-data">
        @method('PUT')
        <x-backend.card>
            <x-slot name="header">
                @lang('Upload Product')
            </x-slot>

            <x-slot name="headerActions">
                <x-utils.link class="card-header-action" :href="route('admin.product.arrival_check')" :text="__('Cancel')"/>
            </x-slot>



            <x-slot name="body">
                <div class="row">

                    <table class="table-bordered w-100">
                        <tr>
                            <th colspan="2" class="text-center">
                                @php
                                    $shopifySlug = json_decode($product->shopify_response);
                                @endphp

                                @if(isset($shopifySlug->product->id))
                                    <a class="text-dark" target="_blank" href="{{config('shopify.shopify_domain').'/admin/products/'.$shopifySlug->product->id}}">
                                        {!! descriptionFormated($product, Setting::option('shopify_title_format'), $shopify = false, $allow_br = false) !!}
                                    </a>
                                @else
                                    {!! descriptionFormated($product, Setting::option('shopify_title_format'), $shopify = false, $allow_br = false) !!}
                                @endif
                            </th>
                        </tr>
                        <tr>
                            <th colspan="2" class="text-center">
                                <a id="downloadAllButton">@lang('Download Images')</a>
                                <div style="display: none;">
                                    @foreach($product->photos as $photo)
                                        <img class="w-100 download_file" src="{{route('download.images', [$photo->id])}}">
                                    @endforeach
                                </div>
                            </th>
                        </tr>
                        <tr>
                            <th class="text-center">Depop Product Information:</th>
                            <th class="text-center">ASOS Product Information:</th>
                        </tr>
                        <tr>
                            @if($product->reworks)
                            <td @if($product->not_depop != 1) onclick="clickToCopy(this)" @endif>
                                {{descriptionFormated($product, Setting::option('rework_depop_title_format'), $shopify = false, $allow_br = false)}}
                            </td>
                            @else
                            <td @if($product->not_depop != 1) onclick="clickToCopy(this)" @endif>
                                {{descriptionFormated($product, Setting::option('depop_title_format'), $shopify = false, $allow_br = false)}}
                            </td>
                            @endif

                            @if($product->reworks)
                            <td @if($product->not_asos != 1) onclick="clickToCopy(this)" @endif>
                                @php
                                    $asos_title = descriptionFormated($product, Setting::option('rework_asos_title_format'), $shopify = false, $allow_br = false);
                                    if(strlen($asos_title) <= 60)
                                    {
                                        echo $asos_title;
                                    }else{
                                        echo substr($asos_title, 0, strpos(wordwrap($asos_title, 60), PHP_EOL));
                                    }
                                @endphp
                            </td>
                            @else
                            <td @if($product->not_asos != 1) onclick="clickToCopy(this)" @endif>
                                @php
                                    $asos_title = descriptionFormated($product, Setting::option('asos_title_format'), $shopify = false, $allow_br = false);
                                    if(strlen($asos_title) <= 60)
                                    {
                                        echo $asos_title;
                                    }else{
                                        echo substr($asos_title, 0, strpos(wordwrap($asos_title, 60), PHP_EOL));
                                    }
                                @endphp
                            </td>
                            @endif
                        </tr>
                        <tr>
                            
                        @if($product->reworks)
                            <td style="background: #ffffcc"; @if($product->not_depop != 1) onclick="clickToCopyTextarea('rework_depop_description_textarea')" @endif>{!! descriptionFormated($product, Setting::option('rework_depop_description_format')) !!}</td>
                            <textarea id="rework_depop_description_textarea">{!! strip_tags(\Str::replace('<br>', PHP_EOL, descriptionFormated($product, Setting::option('rework_depop_description_format')))) !!}</textarea>
                        @else
                        <td @if($product->not_depop != 1) onclick="clickToCopyTextarea('depop_description_textarea')" @endif>{!! descriptionFormated($product, Setting::option('depop_description_format')) !!}</td>
                            <textarea id="depop_description_textarea">{!! strip_tags(\Str::replace('<br>', PHP_EOL, descriptionFormated($product, Setting::option('depop_description_format')))) !!}</textarea>
                        @endif
                        @if($product->reworks)
                            <td style="background: #ffffcc"; @if($product->not_asos != 1) onclick="clickToCopyTextarea('rework_asos_description_textarea')" @endif>{!! descriptionFormated($product, Setting::option('rework_asos_description_format')) !!}</td>
                            <textarea id="rework_asos_description_textarea">{!! strip_tags(\Str::replace('<br>', PHP_EOL, descriptionFormated($product, Setting::option('rework_asos_description_format')))) !!}</textarea>
                        @else
                        <td @if($product->not_asos != 1) onclick="clickToCopyTextarea('asos_description_textarea')" @endif>{!! descriptionFormated($product, Setting::option('asos_description_format')) !!}</td>
                            <textarea id="asos_description_textarea">{!! strip_tags(\Str::replace('<br>', PHP_EOL, descriptionFormated($product, Setting::option('asos_description_format')))) !!}</textarea>
                        @endif
                        </tr>
                        <tr>
                            <td @if($product->not_depop != 1) onclick="clickToCopy(this)" @endif>{{$product->size_on_label}}</td>
                            <td @if($product->not_asos != 1) onclick="clickToCopy(this)" @endif>{{$product->size_on_label}}</td>
                        </tr>
                        <tr>
                            <td @if($product->not_depop != 1) onclick="clickToCopy(this)" @endif>{{priceRound($product->price)}}</td>
                            <td @if($product->not_asos != 1) onclick="clickToCopy(this)" @endif>{{priceRound(ceil($product->price + (8 / 100 * $product->price))-0.1)}}</td>
                        </tr>
                        <tr>
                            <td @if($product->not_depop != 1) onclick="clickToCopy(this)" @endif>{{isset($product->brand->name) ? $product->brand->name : NULL}}</td>
                            <td @if($product->not_asos != 1) onclick="clickToCopy(this)" @endif>{{isset($product->brand->name) ? $product->brand->name : NULL}}</td>
                        </tr>
                        <tr>
                            <td @if($product->not_depop != 1) onclick="clickToCopy(this)" @endif>{{isset($product->type->name) ? $product->type->name : ''}}</td>
                            <td @if($product->not_asos != 1) onclick="clickToCopy(this)" @endif>{{isset($product->type->name) ? $product->type->name : ''}}</td>
                        </tr>
                        @php
                        if($product->gender == "Men's"){
                            $color = "#67a2df";
                        }else{
                            $color = "pink";
                        }
                        @endphp

                        
                        <tr>
                            <td style="background: {{$color}}" @if($product->not_depop != 1) onclick="clickToCopy(this)" @endif>{{$product->gender}}</td>
                            <td style="background: {{$color}}" @if($product->not_asos != 1) onclick="clickToCopy(this)" @endif>{{$product->gender}}</td>
                        </tr>
                        <tr>
                            <td>
                                <div class="form-group col-lg-12">
                                    <input @if($product->not_depop == 1) disabled @endif name="depop_link" value="{{$product->depop_link}}" class="form-control mt-2 w-100" placeholder="Enter a new link to this product Depop" required>
                                </div>
                            </td>
                            <td>
                                <div class="form-group col-lg-12">
                                    <input @if($product->not_asos == 1) disabled @endif  name="asos_link" value="{{$product->asos_link}}" class="form-control mt-2 w-100" placeholder="Enter a new link to this product ASOS" required>
                                </div>
                            </td>
                        </tr>
                    </table>

                </div>
            </x-slot>

            <x-slot name="footer">
                <button class="btn btn-sm btn-primary float-right" type="submit">@lang('Next')</button>
                <p class="btn btn-sm btn-default font-weight-bold float-right" type="submit">{{$model->where('stage', $model::STAGE_UPLOADED)->whereDate('updated_at', today())->count()}} @lang('Uploads today')</p>

            </x-slot>
        </x-backend.card>
    </x-forms.post>
@endsection

@push('after-scripts')
<script>
    function addAnotherVariant(id){
        $('#variants_for_clone'+id).clone().appendTo('#variants_cloned');
    }

    function getProductTypeFields(id)
    {
        $(".type_fields_div").hide();
        $(".type_fields_div_"+id).show();
    }
    $(".type_fields_div_{{$product->type_id}}").show();

    $('#downloadAllButton').click(function() {
        $('img.download_file').each(function() {
            $this = $(this);                      //save the $(this) object
            $('body').append($('<a>')       //append a new '<a>' element to the DOM
                .css('display', 'none')             //hide the new '<a>' element
                .attr('href', $this.attr('src'))  //make the image path the link href
                .attr('download', $this.attr('src').replace('{{Storage::url('products/')}}', ''))           //keep the file name
                .append($this.clone()))       //copy the image into the new '<a>' element
                .find('img:last()')         //obtain a reference to the copied image
                .trigger( 'click' );      //fire the click event

            $('a:last()').remove();
        });
        return false;
    });

</script>
@endpush

@push('after-styles')
    <style>
        table th{
            padding: 10px;
            background: #ebedef4f;
        }
        table td{
            padding: 10px;
            width: 50%;
        }
        table a{
            cursor: pointer;
        }
        table td{
            cursor: grabbing;
            vertical-align: top;
        }
        @if($product->not_depop == 1)
            table td:first-child {
                background: #d8dbe0;
                cursor: not-allowed;
            }
        @endif

        @if($product->not_asos == 1)
            table td:nth-child(2) {
                background: #d8dbe0;
                cursor: not-allowed;
            }
        @endif
        textarea{
            width: 0px;
            height: 0px;
            border:0px;
            resize: none;
            display: none;
        }
    </style>
@endpush

@push('after-scripts')
    <script>
        $("#uploadForm").validate({
            submitHandler: function(form) {
                form.submit();
            }
        });

        $('#uploadForm input').on('keyup blur', function () { // fires on every keyup & blur
            if ($('#uploadForm').valid()) {                   // checks form for validity
                $('#uploadForm button.btn').prop('disabled', false);        // enables button
            } else {
                $('#uploadForm button.btn').prop('disabled', 'disabled');   // disables button
            }
        });

        function clickToCopy(element) {
            var $temp = $("<input>");
            var brRegex = /<br\s*[\/]?>/gi;
            $("body").append($temp);
            $temp.val($(element).text().trim()).select();
            document.execCommand("copy");
            $temp.remove();
            activeSnakeBar('Copied!');
        }

        function clickToCopyTextarea(element) {
            $('#'+element).show();
            $('#'+element).select();
            document.execCommand("copy");
            $('#'+element).hide();
            activeSnakeBar('Copied!');
        }
    </script>
@endpush
